# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/statistics/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/statistics/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .....util.v1 import local_date_time_pb2 as util_dot_v1_dot_local__date__time__pb2
from .....util.v1 import money_pb2 as util_dot_v1_dot_money__pb2
from .....util.v1 import year_month_pb2 as util_dot_v1_dot_year__month__pb2
from .....util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,device/heat_pump/statistics/v1/service.proto\x12\x1e\x64\x65vice.heat_pump.statistics.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dutil/v1/local_date_time.proto\x1a\x13util/v1/money.proto\x1a\x18util/v1/year_month.proto\x1a\x12util/v2/uuid.proto\"\xa3\x02\n\rGetCopRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12+\n\nstart_date\x18\x05 \x01(\x0b\x32\x12.util.v1.YearMonthH\x00\x88\x01\x01\x12\x33\n\x12\x65nd_date_exclusive\x18\x06 \x01(\x0b\x32\x12.util.v1.YearMonthH\x01\x88\x01\x01\x12\x43\n\x0bgranularity\x18\x04 \x01(\x0e\x32..device.heat_pump.statistics.v1.CopGranularityB\r\n\x0b_start_dateB\x15\n\x13_end_date_exclusiveJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\nstart_timeR\x08\x65nd_time\"K\n\x0eGetCopResponse\x12\x39\n\x07\x65ntries\x18\x01 \x03(\x0b\x32(.device.heat_pump.statistics.v1.CopEntry\"\xfc\x01\n\x08\x43opEntry\x12&\n\nstart_date\x18\x04 \x01(\x0b\x32\x12.util.v1.YearMonth\x12#\n\x16room_heating_cop_value\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rdhw_cop_value\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12(\n\x1b\x61verage_outdoor_temperature\x18\x05 \x01(\x01H\x02\x88\x01\x01\x42\x19\n\x17_room_heating_cop_valueB\x10\n\x0e_dhw_cop_valueB\x1e\n\x1c_average_outdoor_temperatureJ\x04\x08\x01\x10\x02R\nstart_time\"\x96\x01\n\x11GetSavingsRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x86\x01\n\x12GetSavingsResponse\x12\x14\n\x0c\x63ost_savings\x18\x01 \x01(\x02\x12\x15\n\rcurrency_code\x18\x02 \x01(\t\x12\x16\n\x0e\x63o2_savings_kg\x18\x03 \x01(\x02\x12\x1d\n\x15number_of_data_points\x18\x04 \x01(\x05\x12\x0c\n\x04show\x18\x05 \x01(\x08\"\xa5\x02\n\x1aGetHeatPumpInsightsRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12/\n\nstart_time\x18\x03 \x01(\x0b\x32\x16.util.v1.LocalDateTimeH\x00\x88\x01\x01\x12\x37\n\x12\x65nd_time_exclusive\x18\x05 \x01(\x0b\x32\x16.util.v1.LocalDateTimeH\x01\x88\x01\x01\x12@\n\x0bgranularity\x18\x04 \x01(\x0e\x32+.device.heat_pump.statistics.v1.GranularityB\r\n\x0b_start_timeB\x15\n\x13_end_time_exclusiveJ\x04\x08\x02\x10\x03R\ntime_range\"|\n\x1bGetHeatPumpInsightsResponse\x12>\n\x08insights\x18\x01 \x03(\x0b\x32,.device.heat_pump.statistics.v1.InsightEntryJ\x04\x08\x02\x10\x03R\x17\x65\x61rliest_available_time\"\xae\x04\n\x0cInsightEntry\x12*\n\nstart_time\x18\x03 \x01(\x0b\x32\x16.util.v1.LocalDateTime\x12\"\n\x15\x65nergy_consumption_wh\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x1e\n\x11\x64\x65livered_heat_wh\x18\x06 \x01(\x01H\x01\x88\x01\x01\x12Z\n\x1d\x65nergy_consumption_wh_problem\x18\x08 \x01(\x0e\x32..device.heat_pump.statistics.v1.InsightProblemH\x02\x88\x01\x01\x12V\n\x19\x64\x65livered_heat_wh_problem\x18\t \x01(\x0e\x32..device.heat_pump.statistics.v1.InsightProblemH\x03\x88\x01\x01\x12\x31\n%is_energy_consumption_wh_interpolated\x18\x05 \x01(\x08\x42\x02\x18\x01\x42\x18\n\x16_energy_consumption_whB\x14\n\x12_delivered_heat_whB \n\x1e_energy_consumption_wh_problemB\x1c\n\x1a_delivered_heat_wh_problemJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x07\x10\x08R\x16\x65nergy_consumption_kwhR!is_interpolated_delivered_heat_whR\ntime_range\"D\n\x1dGetOptimisationSavingsRequest\x12#\n\x0chousehold_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\xc7\x01\n\x1eGetOptimisationSavingsResponse\x12\\\n\x1arolling_month_optimisation\x18\x01 \x01(\x0b\x32\x38.device.heat_pump.statistics.v1.RollingMonthOptimisation\x12G\n\x0fmonthly_savings\x18\x02 \x03(\x0b\x32..device.heat_pump.statistics.v1.MonthlySavings\"\xb9\x01\n\x18RollingMonthOptimisation\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\'\n\x1aweather_optimisation_hours\x18\x02 \x01(\rH\x00\x88\x01\x01\x12$\n\x07savings\x18\x03 \x01(\x0b\x32\x0e.util.v1.MoneyH\x01\x88\x01\x01\x42\x1d\n\x1b_weather_optimisation_hoursB\n\n\x08_savings\"y\n\x0eMonthlySavings\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12!\n\x05month\x18\x02 \x01(\x0b\x32\x12.util.v1.YearMonth\x12\x1f\n\x07savings\x18\x03 \x01(\x0b\x32\x0e.util.v1.Money*N\n\x0e\x43opGranularity\x12\x1f\n\x1b\x43OP_GRANULARITY_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x43OP_GRANULARITY_MONTHLY\x10\x01*r\n\x0bGranularity\x12\x1b\n\x17GRANULARITY_UNSPECIFIED\x10\x00\x12\x16\n\x12GRANULARITY_HOURLY\x10\x01\x12\x15\n\x11GRANULARITY_DAILY\x10\x02\x12\x17\n\x13GRANULARITY_MONTHLY\x10\x03*\xe2\x01\n\x0eInsightProblem\x12\x1f\n\x1bINSIGHT_PROBLEM_UNSPECIFIED\x10\x00\x12\x1d\n\x19INSIGHT_PROBLEM_TOO_EARLY\x10\x01\x12\x1b\n\x17INSIGHT_PROBLEM_OFFLINE\x10\x02\x12\x1a\n\x16INSIGHT_PROBLEM_SENSOR\x10\x03\x12+\n\'INSIGHT_PROBLEM_OFFLINE_TINY_DIFFERENCE\x10\x04\x12*\n&INSIGHT_PROBLEM_SENSOR_TINY_DIFFERENCE\x10\x05\x32\xa4\x04\n\x19HeatPumpStatisticsService\x12g\n\x06GetCop\x12-.device.heat_pump.statistics.v1.GetCopRequest\x1a..device.heat_pump.statistics.v1.GetCopResponse\x12s\n\nGetSavings\x12\x31.device.heat_pump.statistics.v1.GetSavingsRequest\x1a\x32.device.heat_pump.statistics.v1.GetSavingsResponse\x12\x8e\x01\n\x13GetHeatPumpInsights\x12:.device.heat_pump.statistics.v1.GetHeatPumpInsightsRequest\x1a;.device.heat_pump.statistics.v1.GetHeatPumpInsightsResponse\x12\x97\x01\n\x16GetOptimisationSavings\x12=.device.heat_pump.statistics.v1.GetOptimisationSavingsRequest\x1a>.device.heat_pump.statistics.v1.GetOptimisationSavingsResponseB\xd7\x01\n0com.aira.contract.device.heat_pump.statistics.v1B\x0cServiceProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x1d\x44\x65vice.HeatPump.Statistics.V1\xca\x02\x1d\x44\x65vice\\HeatPump\\Statistics\\V1\xe2\x02)Device\\HeatPump\\Statistics\\V1\\GPBMetadata\xea\x02 Device::HeatPump::Statistics::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.statistics.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n0com.aira.contract.device.heat_pump.statistics.v1B\014ServiceProtoP\001\242\002\003DHS\252\002\035Device.HeatPump.Statistics.V1\312\002\035Device\\HeatPump\\Statistics\\V1\342\002)Device\\HeatPump\\Statistics\\V1\\GPBMetadata\352\002 Device::HeatPump::Statistics::V1'
  _globals['_INSIGHTENTRY'].fields_by_name['is_energy_consumption_wh_interpolated']._loaded_options = None
  _globals['_INSIGHTENTRY'].fields_by_name['is_energy_consumption_wh_interpolated']._serialized_options = b'\030\001'
  _globals['_COPGRANULARITY']._serialized_start=2693
  _globals['_COPGRANULARITY']._serialized_end=2771
  _globals['_GRANULARITY']._serialized_start=2773
  _globals['_GRANULARITY']._serialized_end=2887
  _globals['_INSIGHTPROBLEM']._serialized_start=2890
  _globals['_INSIGHTPROBLEM']._serialized_end=3116
  _globals['_GETCOPREQUEST']._serialized_start=212
  _globals['_GETCOPREQUEST']._serialized_end=503
  _globals['_GETCOPRESPONSE']._serialized_start=505
  _globals['_GETCOPRESPONSE']._serialized_end=580
  _globals['_COPENTRY']._serialized_start=583
  _globals['_COPENTRY']._serialized_end=835
  _globals['_GETSAVINGSREQUEST']._serialized_start=838
  _globals['_GETSAVINGSREQUEST']._serialized_end=988
  _globals['_GETSAVINGSRESPONSE']._serialized_start=991
  _globals['_GETSAVINGSRESPONSE']._serialized_end=1125
  _globals['_GETHEATPUMPINSIGHTSREQUEST']._serialized_start=1128
  _globals['_GETHEATPUMPINSIGHTSREQUEST']._serialized_end=1421
  _globals['_GETHEATPUMPINSIGHTSRESPONSE']._serialized_start=1423
  _globals['_GETHEATPUMPINSIGHTSRESPONSE']._serialized_end=1547
  _globals['_INSIGHTENTRY']._serialized_start=1550
  _globals['_INSIGHTENTRY']._serialized_end=2108
  _globals['_GETOPTIMISATIONSAVINGSREQUEST']._serialized_start=2110
  _globals['_GETOPTIMISATIONSAVINGSREQUEST']._serialized_end=2178
  _globals['_GETOPTIMISATIONSAVINGSRESPONSE']._serialized_start=2181
  _globals['_GETOPTIMISATIONSAVINGSRESPONSE']._serialized_end=2380
  _globals['_ROLLINGMONTHOPTIMISATION']._serialized_start=2383
  _globals['_ROLLINGMONTHOPTIMISATION']._serialized_end=2568
  _globals['_MONTHLYSAVINGS']._serialized_start=2570
  _globals['_MONTHLYSAVINGS']._serialized_end=2691
  _globals['_HEATPUMPSTATISTICSSERVICE']._serialized_start=3119
  _globals['_HEATPUMPSTATISTICSSERVICE']._serialized_end=3667
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/state/v1/error.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/state/v1/error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%device/heat_pump/state/v1/error.proto\x12\x19\x64\x65vice.heat_pump.state.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x01\n\x05\x45rror\x12\x35\n\x08severity\x18\x01 \x01(\x0e\x32#.device.heat_pump.state.v1.Severity\x12\x36\n\x03\x63\x63v\x18\x02 \x01(\x0e\x32\'.device.heat_pump.state.v1.CcvErrorCodeH\x00\x12\x38\n\x04\x61ira\x18\x03 \x01(\x0e\x32(.device.heat_pump.state.v1.AiraErrorCodeH\x00\x12/\n\x0boccurred_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\n\x04\x63ode*e\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x15\n\x11SEVERITY_CRITICAL\x10\x01\x12\x12\n\x0eSEVERITY_ERROR\x10\x02\x12\x14\n\x10SEVERITY_WARNING\x10\x03*\x81!\n\x0c\x43\x63vErrorCode\x12\x1e\n\x1a\x43\x43V_ERROR_CODE_UNSPECIFIED\x10\x00\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_AMBIENT_AL_DC\x10\xc8\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_AMBIENT_AL_SC\x10\xc9\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_HP_OUT_AL_DC\x10\xca\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_HP_OUT_AL_SC\x10\xcb\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_HP_IN_AL_DC\x10\xcc\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_HP_IN_AL_SC\x10\xcd\x01\x12\'\n\"CCV_ERROR_CODE_ST_INNER_COIL_AL_DC\x10\xce\x01\x12\'\n\"CCV_ERROR_CODE_ST_INNER_COIL_AL_SC\x10\xcf\x01\x12%\n CCV_ERROR_CODE_ST_DHW_TANK_AL_DC\x10\xd0\x01\x12%\n CCV_ERROR_CODE_ST_DHW_TANK_AL_SC\x10\xd1\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_SUPPLY_AL_DC\x10\xd2\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_SUPPLY_AL_SC\x10\xd3\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY1_AL_DC\x10\xd4\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY1_AL_SC\x10\xd5\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY2_AL_DC\x10\xd6\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_SUPPLY2_AL_SC\x10\xd7\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM1_AL_DC\x10\xdc\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM1_AL_SC\x10\xdd\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM2_AL_DC\x10\xde\x01\x12\"\n\x1d\x43\x43V_ERROR_CODE_ST_ROOM2_AL_SC\x10\xdf\x01\x12?\n;CCV_ERROR_CODE_REGLERING_KOMPRESSOR_FINNS_STOPPANDE_VP_LARM\x10\x38\x12)\n$CCV_ERROR_CODE_MODBUS_KOMM_ALARM_ELM\x10\xb5\x01\x12%\n!CCV_ERROR_CODE_ST_SUPPLY1_AL_HIGH\x10x\x12%\n!CCV_ERROR_CODE_ST_SUPPLY2_AL_HIGH\x10z\x12\'\n\"CCV_ERROR_CODE_WARNING_FLOW_TO_LOW\x10\x80\x01\x12$\n CCV_ERROR_CODE_ALARM_FLOW_TO_LOW\x10\x7f\x12-\n(CCV_ERROR_CODE_ST_HP_OUT_AL_HIGH_3_TIMES\x10\xa0\x01\x12%\n CCV_ERROR_CODE_ST_HP_OUT_AL_HIGH\x10\xa1\x01\x12,\n\'CCV_ERROR_CODE_ST_HP_OUT_AL_LOW_3_TIMES\x10\xa2\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_HP_OUT_AL_LOW\x10\xa3\x01\x12,\n\'CCV_ERROR_CODE_ST_HP_IN_AL_HIGH_3_TIMES\x10\xa5\x01\x12$\n\x1f\x43\x43V_ERROR_CODE_ST_HP_IN_AL_HIGH\x10\xa6\x01\x12+\n&CCV_ERROR_CODE_ST_HP_IN_AL_LOW_3_TIMES\x10\xa7\x01\x12#\n\x1e\x43\x43V_ERROR_CODE_ST_HP_IN_AL_LOW\x10\xa8\x01\x12\x30\n+CCV_ERROR_CODE_ST_INNER_COIL_AL_LOW_3_TIMES\x10\xa9\x01\x12(\n#CCV_ERROR_CODE_ST_INNER_COIL_AL_LOW\x10\xaa\x01\x12\x30\n+CCV_ERROR_CODE_WARNING_LEGIO_NOT_SUCCESSFUL\x10\xad\x01\x12(\n#CCV_ERROR_CODE_FLOW_LEVEL_2_TOO_LOW\x10\xb6\x01\x12\x30\n+CCV_ERROR_CODE_FLOW_LEVEL_2_TOO_LOW_3_TIMES\x10\xb7\x01\x12(\n#CCV_ERROR_CODE_FLOW_LEVEL_1_TOO_LOW\x10\xb8\x01\x12\x30\n+CCV_ERROR_CODE_FLOW_LEVEL_1_TOO_LOW_3_TIMES\x10\xb9\x01\x12-\n(CCV_ERROR_CODE_WARNING_ANTIFREEZE_ACTIVE\x10\xba\x01\x12.\n)CCV_ERROR_CODE_DEFROST_OUTLET_LOW_3_TIMES\x10\xbd\x01\x12&\n!CCV_ERROR_CODE_DEFROST_OUTLET_LOW\x10\xbe\x01\x12)\n$CCV_ERROR_CODE_ES_MEGMET_SUM_C_ALARM\x10\xab\x02\x12)\n$CCV_ERROR_CODE_ES_MEGMET_SUM_E_ALARM\x10\xac\x02\x12*\n%CCV_ERROR_CODE_ES_MEGMET_SUM_COMERROR\x10\xad\x02\x12(\n#CCV_ERROR_CODE_MAIN_LINE_PROTECTION\x10\xae\x02\x12\x37\n2CCV_ERROR_CODE_COMPRESSOR_PHASE_CURRENT_PROTECTION\x10\xaf\x02\x12)\n$CCV_ERROR_CODE_IPM_MODULE_PROTECTION\x10\xb0\x02\x12\x34\n/CCV_ERROR_CODE_COMPRESSOR_OIL_RETURN_PROTECTION\x10\xb1\x02\x12\x33\n.CCV_ERROR_CODE_HIGH_PRESSURE_SWITCH_PROTECTION\x10\xb2\x02\x12\x37\n2CCV_ERROR_CODE_COMPRESSOR_SPEED_DOWN_HIGH_PRESSURE\x10\xb3\x02\x12\x33\n.CCV_ERROR_CODE_FIRST_START_PRE_HEAT_PROTECTION\x10\xb4\x02\x12\x34\n/CCV_ERROR_CODE_OUTDOOR_GAS_DISCHARGE_PROTECTION\x10\xb5\x02\x12\x36\n1CCV_ERROR_CODE_OUTDOOR_EVAPORATOR_COIL_PROTECTION\x10\xb6\x02\x12\'\n\"CCV_ERROR_CODE_AC_HIGH_LOW_VOLTAGE\x10\xb7\x02\x12\x32\n-CCV_ERROR_CODE_FAILURE_CAUSED_BY_AMBIENT_TEMP\x10\xb8\x02\x12\x32\n-CCV_ERROR_CODE_FREQUNCY_LIMIT_BY_AMBIENT_TEMP\x10\xb9\x02\x12\x32\n-CCV_ERROR_CODE_LOW_PRESSURE_SWITCH_PROTECTION\x10\xba\x02\x12\x36\n1CCV_ERROR_CODE_COMPRESSOR_SPEED_DOWN_LOW_PRESSURE\x10\xbb\x02\x12\x30\n+CCV_ERROR_CODE_OUTDOOR_AMBIENT_TEMP_FAILURE\x10\xbc\x02\x12\x33\n.CCV_ERROR_CODE_OUTDOOR_EVAPORATOR_COIL_FAILURE\x10\xbd\x02\x12\x31\n,CCV_ERROR_CODE_OUTDOOR_GAS_DISCHARGE_FAILURE\x10\xbe\x02\x12.\n)CCV_ERROR_CODE_OUTDOOR_GAS_RETURN_FAILURE\x10\xbf\x02\x12/\n*CCV_ERROR_CODE_EVAPORATOR_PRESSURE_FAILURE\x10\xc0\x02\x12.\n)CCV_ERROR_CODE_CONDENSER_PRESSURE_FAILURE\x10\xc1\x02\x12\x38\n3CCV_ERROR_CODE_HIGH_PRESSURE_SWITCH_LOCK_PROTECTION\x10\xc2\x02\x12\x37\n2CCV_ERROR_CODE_LOW_PRESSURE_SWITCH_LOCK_PROTECTION\x10\xc3\x02\x12$\n\x1f\x43\x43V_ERROR_CODE_DC_FAN_A_FAILURE\x10\xc4\x02\x12$\n\x1f\x43\x43V_ERROR_CODE_DC_FAN_B_FAILURE\x10\xc5\x02\x12\x38\n3CCV_ERROR_CODE_EVAPORATING_PRESSURE_LOCK_PROTECTION\x10\xc6\x02\x12\x36\n1CCV_ERROR_CODE_CONDENSER_PRESSURE_LOCK_PROTECTION\x10\xc7\x02\x12:\n5CCV_ERROR_CODE_MASTER_AND_SLAVE_COMMUNICATION_FAILURE\x10\xc8\x02\x12M\nHCCV_ERROR_CODE_OUTDOOR_MAIN_CONTROL_PCB_AND_MODULE_COMMUNICATION_FAILURE\x10\xc9\x02\x12\x34\n/CCV_ERROR_CODE_COMPRESSOR_PHASE_CURRENT_FAILURE\x10\xca\x02\x12\x35\n0CCV_ERROR_CODE_COMPRESSOR_PHASE_CURRENT_OVERLOAD\x10\xcb\x02\x12-\n(CCV_ERROR_CODE_COMPRESSOR_DRIVER_FAILURE\x10\xcc\x02\x12<\n7CCV_ERROR_CODE_MODULE_VDC_OVER_HIGH_LOW_VOLTAGE_FAILURE\x10\xcd\x02\x12&\n!CCV_ERROR_CODE_AC_CURRENT_FAILURE\x10\xce\x02\x12\"\n\x1d\x43\x43V_ERROR_CODE_EEPROM_FAILURE\x10\xcf\x02\x12)\n$CCV_ERROR_CODE_FAN_DRIVE_PCB_FAILURE\x10\xd0\x02\x12,\n\'CCV_ERROR_CODE_INLET_WATER_TEMP_FAILURE\x10\xd1\x02\x12-\n(CCV_ERROR_CODE_OUTLET_WATER_TEMP_FAILURE\x10\xd2\x02\x12+\n&CCV_ERROR_CODE_INNER_COIL_TEMP_FAILURE\x10\xd3\x02\x12)\n$CCV_ERROR_CODE_DC_WATER_PUMP_FAILURE\x10\xd4\x02\x12,\n\'CCV_ERROR_CODE_COMPRESSOR_STOPPED_ALARM\x10\xdd\x02\x12\x32\n-CCV_ERROR_CODE_COMPRESSOR_STOPPED_OUTLET_TEMP\x10\xde\x02\x12\x36\n1CCV_ERROR_CODE_COMPRESSOR_STOPPED_INNER_COIL_TEMP\x10\xdf\x02\x12/\n*CCV_ERROR_CODE_ST_SUPPLY1_AL_CRITICAL_HIGH\x10\xc2\x01\x12/\n*CCV_ERROR_CODE_ST_SUPPLY2_AL_CRITICAL_HIGH\x10\xc3\x01*\xe0\x01\n\rAiraErrorCode\x12\x1f\n\x1b\x41IRA_ERROR_CODE_UNSPECIFIED\x10\x00\x12\x1d\n\x19\x41IRA_ERROR_CODE_WIFI_RSSI\x10\x01\x12+\n\'AIRA_ERROR_CODE_ANTI_LEGIONELLA_TIMEOUT\x10\x02\x12\x30\n,AIRA_ERROR_CODE_THERMOSTAT_DISCONNECT_ZONE_1\x10\x03\x12\x30\n,AIRA_ERROR_CODE_THERMOSTAT_DISCONNECT_ZONE_2\x10\x04\x42\xbc\x01\n+com.aira.contract.device.heat_pump.state.v1B\nErrorProtoP\x01\xa2\x02\x03\x44HS\xaa\x02\x18\x44\x65vice.HeatPump.State.V1\xca\x02\x18\x44\x65vice\\HeatPump\\State\\V1\xe2\x02$Device\\HeatPump\\State\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::State::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.state.v1.error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.state.v1B\nErrorProtoP\001\242\002\003DHS\252\002\030Device.HeatPump.State.V1\312\002\030Device\\HeatPump\\State\\V1\342\002$Device\\HeatPump\\State\\V1\\GPBMetadata\352\002\033Device::HeatPump::State::V1'
  _globals['_SEVERITY']._serialized_start=337
  _globals['_SEVERITY']._serialized_end=438
  _globals['_CCVERRORCODE']._serialized_start=441
  _globals['_CCVERRORCODE']._serialized_end=4666
  _globals['_AIRAERRORCODE']._serialized_start=4669
  _globals['_AIRAERRORCODE']._serialized_end=4893
  _globals['_ERROR']._serialized_start=102
  _globals['_ERROR']._serialized_end=335
# @@protoc_insertion_point(module_scope)


from .utils import Utils
from .exceptions import NotLoggedInException, AuthenticationError, UnknownTypeException, UnknownCommandException, TokenError

__all__ = ['Utils', 'NotLoggedInException', 'AuthenticationError', 'UnknownTypeException', 'UnknownCommandException', 'TokenError']


""" Useful functions """
# utils/utils.py

from google.protobuf.message import Message
from google.protobuf.json_format import MessageToDict
from ..util.v1 import uuid_pb2
from base64 import b64decode
from .exceptions import UnknownTypeException

class Utils:
    @staticmethod
    def convert_to_dict(response: Message):
        """ Convert a protobuf response to a dictionary. """
        return MessageToDict(response,
                             preserving_proto_field_name=True,
                             use_integers_for_enums=False,
                             always_print_fields_with_no_presence=True)

    @staticmethod
    def convert_to_uuid_list(device_ids):
        if isinstance(device_ids, list):
            if all(isinstance(device_id, uuid_pb2.Uuid) for device_id in device_ids):
                heat_pump_ids = device_ids
            elif all(isinstance(device_id, str) for device_id in device_ids):
                heat_pump_ids = [uuid_pb2.Uuid(value=b64decode(str.encode(device_id))) for device_id in device_ids]
            else:
                raise UnknownTypeException(f"Unknown type for {device_ids} list")
        if isinstance(device_ids, uuid_pb2.Uuid): # convert to list if given as single uuid
            heat_pump_ids = [device_ids]
        elif isinstance(device_ids, str): # convert to list of uuids if given in base64
            heat_pump_ids = [uuid_pb2.Uuid(value=b64decode(str.encode(device_ids)))]
        else: # unknown type
            raise UnknownTypeException(f"Unknown type for {device_ids}")

        return heat_pump_ids


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/cloud/v1/service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/cloud/v1/service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...command.v1 import command_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__pb2
from ...command.v1 import command_progress_pb2 as device_dot_heat__pump_dot_command_dot_v1_dot_command__progress__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from .....util.v1 import type_of_day_pb2 as util_dot_v1_dot_type__of__day__pb2
from .....util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2
from .....util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from .....util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'device/heat_pump/cloud/v1/service.proto\x12\x19\x64\x65vice.heat_pump.cloud.v1\x1a)device/heat_pump/command/v1/command.proto\x1a\x32\x64\x65vice/heat_pump/command/v1/command_progress.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19util/v1/type_of_day.proto\x1a\x12util/v1/uuid.proto\x1a\x14util/v2/market.proto\x1a\x12util/v2/uuid.proto\"p\n\x12SendCommandRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12\x35\n\x07\x63ommand\x18\x02 \x01(\x0b\x32$.device.heat_pump.command.v1.Command\"8\n\x13SendCommandResponse\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"A\n\x1cStreamCommandProgressRequest\x12!\n\ncommand_id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"g\n\x1dStreamCommandProgressResponse\x12\x46\n\x10\x63ommand_progress\x18\x01 \x01(\x0b\x32,.device.heat_pump.command.v1.CommandProgress\"\xaa\x01\n\x11ScheduledAwayMode\x12#\n\x0cheat_pump_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12.\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x05 \x01(\tJ\x04\x08\x01\x10\x02\"d\n\x17ScheduleAwayModeRequest\x12I\n\x13scheduled_away_mode\x18\x01 \x01(\x0b\x32,.device.heat_pump.cloud.v1.ScheduledAwayMode\"I\n\x18ScheduleAwayModeResponse\x12-\n\x16scheduled_away_mode_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"B\n\x1bGetScheduledAwayModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"i\n\x1cGetScheduledAwayModeResponse\x12I\n\x13scheduled_away_mode\x18\x01 \x01(\x0b\x32,.device.heat_pump.cloud.v1.ScheduledAwayMode\"E\n\x1e\x44\x65leteScheduledAwayModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\'\n\x1f\x44\x65leteScheduledAwayModeResponseJ\x04\x08\x01\x10\x02\"?\n\x18ScheduleNightModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x1b\n\x19ScheduleNightModeResponse\"F\n\x1f\x44\x65leteScheduledNightModeRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\"\n DeleteScheduledNightModeResponse\"\x9b\x01\n\x15SetDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12<\n\x07\x65ntries\x18\x02 \x03(\x0b\x32+.device.heat_pump.cloud.v1.DhwScheduleEntry\x12\x1f\n\x06market\x18\x03 \x01(\x0e\x32\x0f.util.v2.Market\"\x18\n\x16SetDhwScheduleResponse\"\xb1\x01\n\x10\x44hwScheduleEntry\x12\x17\n\nstart_hour\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x15\n\x08\x65nd_hour\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\'\n\x0btype_of_day\x18\x03 \x01(\x0e\x32\x12.util.v1.TypeOfDay\x12\x18\n\x0btemperature\x18\x04 \x01(\rH\x02\x88\x01\x01\x42\r\n\x0b_start_hourB\x0b\n\t_end_hourB\x0e\n\x0c_temperature\"<\n\x15GetDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"V\n\x16GetDhwScheduleResponse\x12<\n\x07\x65ntries\x18\x01 \x03(\x0b\x32+.device.heat_pump.cloud.v1.DhwScheduleEntry\"?\n\x18\x44\x65leteDhwScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x1b\n\x19\x44\x65leteDhwScheduleResponse\"\xae\x01\n\x1cSetLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x36\n\rnext_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x1f\n\x06market\x18\x03 \x01(\x0e\x32\x0f.util.v2.MarketB\x10\n\x0e_next_run_time\"\x1f\n\x1dSetLegionellaScheduleResponse\"C\n\x1cGetLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x8e\x01\n\x1dGetLegionellaScheduleResponse\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x36\n\rnext_run_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x10\n\x0e_next_run_time\"F\n\x1f\x44\x65leteLegionellaScheduleRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\"\n DeleteLegionellaScheduleResponse2\xe1\r\n\x14HeatPumpCloudService\x12l\n\x0bSendCommand\x12-.device.heat_pump.cloud.v1.SendCommandRequest\x1a..device.heat_pump.cloud.v1.SendCommandResponse\x12\x8c\x01\n\x15StreamCommandProgress\x12\x37.device.heat_pump.cloud.v1.StreamCommandProgressRequest\x1a\x38.device.heat_pump.cloud.v1.StreamCommandProgressResponse0\x01\x12{\n\x10ScheduleAwayMode\x12\x32.device.heat_pump.cloud.v1.ScheduleAwayModeRequest\x1a\x33.device.heat_pump.cloud.v1.ScheduleAwayModeResponse\x12\x87\x01\n\x14GetScheduledAwayMode\x12\x36.device.heat_pump.cloud.v1.GetScheduledAwayModeRequest\x1a\x37.device.heat_pump.cloud.v1.GetScheduledAwayModeResponse\x12\x90\x01\n\x17\x44\x65leteScheduledAwayMode\x12\x39.device.heat_pump.cloud.v1.DeleteScheduledAwayModeRequest\x1a:.device.heat_pump.cloud.v1.DeleteScheduledAwayModeResponse\x12~\n\x11ScheduleNightMode\x12\x33.device.heat_pump.cloud.v1.ScheduleNightModeRequest\x1a\x34.device.heat_pump.cloud.v1.ScheduleNightModeResponse\x12\x93\x01\n\x18\x44\x65leteScheduledNightMode\x12:.device.heat_pump.cloud.v1.DeleteScheduledNightModeRequest\x1a;.device.heat_pump.cloud.v1.DeleteScheduledNightModeResponse\x12u\n\x0eSetDhwSchedule\x12\x30.device.heat_pump.cloud.v1.SetDhwScheduleRequest\x1a\x31.device.heat_pump.cloud.v1.SetDhwScheduleResponse\x12u\n\x0eGetDhwSchedule\x12\x30.device.heat_pump.cloud.v1.GetDhwScheduleRequest\x1a\x31.device.heat_pump.cloud.v1.GetDhwScheduleResponse\x12~\n\x11\x44\x65leteDhwSchedule\x12\x33.device.heat_pump.cloud.v1.DeleteDhwScheduleRequest\x1a\x34.device.heat_pump.cloud.v1.DeleteDhwScheduleResponse\x12\x8a\x01\n\x15SetLegionellaSchedule\x12\x37.device.heat_pump.cloud.v1.SetLegionellaScheduleRequest\x1a\x38.device.heat_pump.cloud.v1.SetLegionellaScheduleResponse\x12\x8a\x01\n\x15GetLegionellaSchedule\x12\x37.device.heat_pump.cloud.v1.GetLegionellaScheduleRequest\x1a\x38.device.heat_pump.cloud.v1.GetLegionellaScheduleResponse\x12\x93\x01\n\x18\x44\x65leteLegionellaSchedule\x12:.device.heat_pump.cloud.v1.DeleteLegionellaScheduleRequest\x1a;.device.heat_pump.cloud.v1.DeleteLegionellaScheduleResponseB\xbe\x01\n+com.aira.contract.device.heat_pump.cloud.v1B\x0cServiceProtoP\x01\xa2\x02\x03\x44HC\xaa\x02\x18\x44\x65vice.HeatPump.Cloud.V1\xca\x02\x18\x44\x65vice\\HeatPump\\Cloud\\V1\xe2\x02$Device\\HeatPump\\Cloud\\V1\\GPBMetadata\xea\x02\x1b\x44\x65vice::HeatPump::Cloud::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.cloud.v1.service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n+com.aira.contract.device.heat_pump.cloud.v1B\014ServiceProtoP\001\242\002\003DHC\252\002\030Device.HeatPump.Cloud.V1\312\002\030Device\\HeatPump\\Cloud\\V1\342\002$Device\\HeatPump\\Cloud\\V1\\GPBMetadata\352\002\033Device::HeatPump::Cloud::V1'
  _globals['_SENDCOMMANDREQUEST']._serialized_start=287
  _globals['_SENDCOMMANDREQUEST']._serialized_end=399
  _globals['_SENDCOMMANDRESPONSE']._serialized_start=401
  _globals['_SENDCOMMANDRESPONSE']._serialized_end=457
  _globals['_STREAMCOMMANDPROGRESSREQUEST']._serialized_start=459
  _globals['_STREAMCOMMANDPROGRESSREQUEST']._serialized_end=524
  _globals['_STREAMCOMMANDPROGRESSRESPONSE']._serialized_start=526
  _globals['_STREAMCOMMANDPROGRESSRESPONSE']._serialized_end=629
  _globals['_SCHEDULEDAWAYMODE']._serialized_start=632
  _globals['_SCHEDULEDAWAYMODE']._serialized_end=802
  _globals['_SCHEDULEAWAYMODEREQUEST']._serialized_start=804
  _globals['_SCHEDULEAWAYMODEREQUEST']._serialized_end=904
  _globals['_SCHEDULEAWAYMODERESPONSE']._serialized_start=906
  _globals['_SCHEDULEAWAYMODERESPONSE']._serialized_end=979
  _globals['_GETSCHEDULEDAWAYMODEREQUEST']._serialized_start=981
  _globals['_GETSCHEDULEDAWAYMODEREQUEST']._serialized_end=1047
  _globals['_GETSCHEDULEDAWAYMODERESPONSE']._serialized_start=1049
  _globals['_GETSCHEDULEDAWAYMODERESPONSE']._serialized_end=1154
  _globals['_DELETESCHEDULEDAWAYMODEREQUEST']._serialized_start=1156
  _globals['_DELETESCHEDULEDAWAYMODEREQUEST']._serialized_end=1225
  _globals['_DELETESCHEDULEDAWAYMODERESPONSE']._serialized_start=1227
  _globals['_DELETESCHEDULEDAWAYMODERESPONSE']._serialized_end=1266
  _globals['_SCHEDULENIGHTMODEREQUEST']._serialized_start=1268
  _globals['_SCHEDULENIGHTMODEREQUEST']._serialized_end=1331
  _globals['_SCHEDULENIGHTMODERESPONSE']._serialized_start=1333
  _globals['_SCHEDULENIGHTMODERESPONSE']._serialized_end=1360
  _globals['_DELETESCHEDULEDNIGHTMODEREQUEST']._serialized_start=1362
  _globals['_DELETESCHEDULEDNIGHTMODEREQUEST']._serialized_end=1432
  _globals['_DELETESCHEDULEDNIGHTMODERESPONSE']._serialized_start=1434
  _globals['_DELETESCHEDULEDNIGHTMODERESPONSE']._serialized_end=1468
  _globals['_SETDHWSCHEDULEREQUEST']._serialized_start=1471
  _globals['_SETDHWSCHEDULEREQUEST']._serialized_end=1626
  _globals['_SETDHWSCHEDULERESPONSE']._serialized_start=1628
  _globals['_SETDHWSCHEDULERESPONSE']._serialized_end=1652
  _globals['_DHWSCHEDULEENTRY']._serialized_start=1655
  _globals['_DHWSCHEDULEENTRY']._serialized_end=1832
  _globals['_GETDHWSCHEDULEREQUEST']._serialized_start=1834
  _globals['_GETDHWSCHEDULEREQUEST']._serialized_end=1894
  _globals['_GETDHWSCHEDULERESPONSE']._serialized_start=1896
  _globals['_GETDHWSCHEDULERESPONSE']._serialized_end=1982
  _globals['_DELETEDHWSCHEDULEREQUEST']._serialized_start=1984
  _globals['_DELETEDHWSCHEDULEREQUEST']._serialized_end=2047
  _globals['_DELETEDHWSCHEDULERESPONSE']._serialized_start=2049
  _globals['_DELETEDHWSCHEDULERESPONSE']._serialized_end=2076
  _globals['_SETLEGIONELLASCHEDULEREQUEST']._serialized_start=2079
  _globals['_SETLEGIONELLASCHEDULEREQUEST']._serialized_end=2253
  _globals['_SETLEGIONELLASCHEDULERESPONSE']._serialized_start=2255
  _globals['_SETLEGIONELLASCHEDULERESPONSE']._serialized_end=2286
  _globals['_GETLEGIONELLASCHEDULEREQUEST']._serialized_start=2288
  _globals['_GETLEGIONELLASCHEDULEREQUEST']._serialized_end=2355
  _globals['_GETLEGIONELLASCHEDULERESPONSE']._serialized_start=2358
  _globals['_GETLEGIONELLASCHEDULERESPONSE']._serialized_end=2500
  _globals['_DELETELEGIONELLASCHEDULEREQUEST']._serialized_start=2502
  _globals['_DELETELEGIONELLASCHEDULEREQUEST']._serialized_end=2572
  _globals['_DELETELEGIONELLASCHEDULERESPONSE']._serialized_start=2574
  _globals['_DELETELEGIONELLASCHEDULERESPONSE']._serialized_end=2608
  _globals['_HEATPUMPCLOUDSERVICE']._serialized_start=2611
  _globals['_HEATPUMPCLOUDSERVICE']._serialized_end=4372
# @@protoc_insertion_point(module_scope)


# exceptions/exceptions.py

class NotLoggedInException(Exception):
    """ Exception raised when a user is not logged in. """
    pass

class AuthenticationError(Exception):
    """ Exception raised for authentication errors. """
    pass

class UnknownTypeException(Exception):
    """ Exception raised for unknown types. """
    pass

class UnknownCommandException(Exception):
    """ Exception raised for unknown commands. """
    pass

class TokenError(Exception):
    """ Exception raised for token errors. """
    pass




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/config/v1/ccv/v1/ccv_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/config/v1/ccv/v1/ccv_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import heat_curve_pb2 as device_dot_heat__pump_dot_config_dot_v1_dot_ccv_dot_v1_dot_heat__curve__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2device/heat_pump/config/v1/ccv/v1/ccv_config.proto\x12!device.heat_pump.config.v1.ccv.v1\x1a\x32\x64\x65vice/heat_pump/config/v1/ccv/v1/heat_curve.proto\"\x81\x08\n\rSensorSources\x12\x34\n\'outdoor_unit_ambient_temperature_source\x18\x01 \x01(\rH\x00\x88\x01\x01\x12\x33\n&outdoor_unit_supply_temperature_source\x18\x02 \x01(\rH\x01\x88\x01\x01\x12\x33\n&outdoor_unit_return_temperature_source\x18\x03 \x01(\rH\x02\x88\x01\x01\x12\x37\n*outdoor_unit_inner_coil_temperature_source\x18\x04 \x01(\rH\x03\x88\x01\x01\x12\x34\n\'indoor_unit_dhw_tank_temperature_source\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x32\n%indoor_unit_supply_temperature_source\x18\x06 \x01(\rH\x05\x88\x01\x01\x12\x39\n,indoor_unit_supply_temperature_zone_1_source\x18\x07 \x01(\rH\x06\x88\x01\x01\x12\x39\n,indoor_unit_supply_temperature_zone_2_source\x18\x08 \x01(\rH\x07\x88\x01\x01\x12\x37\n*indoor_unit_room_temperature_zone_1_source\x18\t \x01(\rH\x08\x88\x01\x01\x12\x37\n*indoor_unit_room_temperature_zone_2_source\x18\n \x01(\rH\t\x88\x01\x01\x42*\n(_outdoor_unit_ambient_temperature_sourceB)\n\'_outdoor_unit_supply_temperature_sourceB)\n\'_outdoor_unit_return_temperature_sourceB-\n+_outdoor_unit_inner_coil_temperature_sourceB*\n(_indoor_unit_dhw_tank_temperature_sourceB(\n&_indoor_unit_supply_temperature_sourceB/\n-_indoor_unit_supply_temperature_zone_1_sourceB/\n-_indoor_unit_supply_temperature_zone_2_sourceB-\n+_indoor_unit_room_temperature_zone_1_sourceB-\n+_indoor_unit_room_temperature_zone_2_source\"\x86\n\n\x12\x43ompressorSettings\x12+\n\x1eminimum_time_start_start_cycle\x18\x03 \x01(\x05H\x00\x88\x01\x01\x12*\n\x1dminimum_time_stop_start_cycle\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12&\n\x19p0_compressor_prerun_time\x18\x05 \x01(\x05H\x02\x88\x01\x01\x12,\n\x1f\x64hw_diverting_valve_prerun_time\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12(\n\x1bp0_compressor_afterrun_time\x18\x07 \x01(\x05H\x04\x88\x01\x01\x12*\n\x1d\x64iverting_valve_afterrun_time\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12%\n\x18p0_autostart_temperature\x18\t \x01(\x02H\x06\x88\x01\x01\x12\'\n\x1amaximum_outlet_temperature\x18\n \x01(\x02H\x07\x88\x01\x01\x12\'\n\x1aminimum_outlet_temperature\x18\x0b \x01(\x02H\x08\x88\x01\x01\x12&\n\x19maximum_inlet_temperature\x18\x0c \x01(\x02H\t\x88\x01\x01\x12&\n\x19minimum_inlet_temperature\x18\r \x01(\x02H\n\x88\x01\x01\x12+\n\x1eminimum_inner_coil_temperature\x18\x0e \x01(\x02H\x0b\x88\x01\x01\x12\"\n\x15\x63ompressor_limit_time\x18\x11 \x01(\x02H\x0c\x88\x01\x01\x12-\n compressor_inner_coil_block_time\x18\x10 \x01(\x05H\r\x88\x01\x01\x12\'\n\x16\x64\x65precated_speed_level\x18\x01 \x01(\x05\x42\x02\x18\x01H\x0e\x88\x01\x01\x12(\n\x17\x64\x65precated_working_mode\x18\x02 \x01(\x05\x42\x02\x18\x01H\x0f\x88\x01\x01\x12\x31\n deprecated_compressor_limit_time\x18\x0f \x01(\x05\x42\x02\x18\x01H\x10\x88\x01\x01\x42!\n\x1f_minimum_time_start_start_cycleB \n\x1e_minimum_time_stop_start_cycleB\x1c\n\x1a_p0_compressor_prerun_timeB\"\n _dhw_diverting_valve_prerun_timeB\x1e\n\x1c_p0_compressor_afterrun_timeB \n\x1e_diverting_valve_afterrun_timeB\x1b\n\x19_p0_autostart_temperatureB\x1d\n\x1b_maximum_outlet_temperatureB\x1d\n\x1b_minimum_outlet_temperatureB\x1c\n\x1a_maximum_inlet_temperatureB\x1c\n\x1a_minimum_inlet_temperatureB!\n\x1f_minimum_inner_coil_temperatureB\x18\n\x16_compressor_limit_timeB#\n!_compressor_inner_coil_block_timeB\x19\n\x17_deprecated_speed_levelB\x1a\n\x18_deprecated_working_modeB#\n!_deprecated_compressor_limit_time\"\xad\x01\n\x15\x44omesticHotWaterBoost\x12#\n\x16tank_temp_boost_change\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12\x30\n\x1f\x64\x65precated_remaining_boost_time\x18\x01 \x01(\x05\x42\x02\x18\x01H\x01\x88\x01\x01\x42\x19\n\x17_tank_temp_boost_changeB\"\n _deprecated_remaining_boost_time\"U\n\x0bPiRegulator\x12\x15\n\x08p_factor\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x15\n\x08i_factor\x18\x02 \x01(\x02H\x01\x88\x01\x01\x42\x0b\n\t_p_factorB\x0b\n\t_i_factor\"\xfe\x03\n\rHeatingSystem\x12\x19\n\x0cheating_time\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x15\n\x08\x64hw_time\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x46\n9minimum_inline_heater_cooling_time_before_compressor_stop\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x1c\n\x0fheat_balance_a0\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12\x1c\n\x0fheat_balance_a2\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12\x19\n\x0c\x63ooling_time\x18\x07 \x01(\x05H\x05\x88\x01\x01\x12\x1c\n\x0f\x63ool_balance_k0\x18\x08 \x01(\x05H\x06\x88\x01\x01\x12U\n\x1d\x63ompressor_speed_pi_regulator\x18\t \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x0f\n\r_heating_timeB\x0b\n\t_dhw_timeB<\n:_minimum_inline_heater_cooling_time_before_compressor_stopB\x12\n\x10_heat_balance_a0B\x12\n\x10_heat_balance_a2B\x0f\n\r_cooling_timeB\x12\n\x10_cool_balance_k0\"\xc2\x02\n\x12LegionellaSettings\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12 \n\x13interval_time_start\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x1f\n\x12interval_time_stop\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x1d\n\x10maximum_duration\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x1f\n\x12target_temperature\x18\x05 \x01(\x02H\x04\x88\x01\x01\x12\x1a\n\rinterval_days\x18\x06 \x01(\x05H\x05\x88\x01\x01\x42\n\n\x08_enabledB\x16\n\x14_interval_time_startB\x15\n\x13_interval_time_stopB\x13\n\x11_maximum_durationB\x15\n\x13_target_temperatureB\x10\n\x0e_interval_days\"\xee\x04\n\tDhwSystem\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x19\n\x0c\x64hw_setpoint\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x1e\n\x11\x64hw_setpoint_diff\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12G\n\x05\x62oost\x18\x04 \x01(\x0b\x32\x38.device.heat_pump.config.v1.ccv.v1.DomesticHotWaterBoost\x12*\n\x1dtank_temperature_night_change\x18\x05 \x01(\x02H\x03\x88\x01\x01\x12&\n\x19\x63ompressor_speed_dhw_mode\x18\x06 \x01(\x05H\x04\x88\x01\x01\x12)\n\x1cmaximum_setpoint_temperature\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x34\n\'unacknowledged_alarm_temperature_change\x18\x08 \x01(\x02H\x06\x88\x01\x01\x12R\n\x13legionella_settings\x18\t \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.LegionellaSettingsB\n\n\x08_enabledB\x0f\n\r_dhw_setpointB\x14\n\x12_dhw_setpoint_diffB \n\x1e_tank_temperature_night_changeB\x1c\n\x1a_compressor_speed_dhw_modeB\x1f\n\x1d_maximum_setpoint_temperatureB*\n(_unacknowledged_alarm_temperature_change\"\xe1\x02\n\x0fZoneMixingValve\x12\x1c\n\x0f\x63ontrol_enabled\x18\x04 \x01(\x08H\x00\x88\x01\x01\x12#\n\x16regulation_period_time\x18\x01 \x01(\x05H\x01\x88\x01\x01\x12$\n\x17\x65nd_to_end_running_time\x18\x02 \x01(\x05H\x02\x88\x01\x01\x12.\n!minimum_relay_output_pulse_length\x18\x03 \x01(\x05H\x03\x88\x01\x01\x12\x44\n\x0cpi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x12\n\x10_control_enabledB\x19\n\x17_regulation_period_timeB\x1a\n\x18_end_to_end_running_timeB$\n\"_minimum_relay_output_pulse_length\"\xba\x02\n\x13ZoneHeatingSettings\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rroom_setpoint\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12$\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12$\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12O\n\nheat_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearHeatCurveB\n\n\x08_enabledB\x10\n\x0e_room_setpointB\x1a\n\x18_minimum_supply_setpointB\x1a\n\x18_maximum_supply_setpoint\"\xba\x02\n\x13ZoneCoolingSettings\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1a\n\rroom_setpoint\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12$\n\x17minimum_supply_setpoint\x18\x03 \x01(\x02H\x02\x88\x01\x01\x12$\n\x17maximum_supply_setpoint\x18\x04 \x01(\x02H\x03\x88\x01\x01\x12O\n\ncool_curve\x18\x05 \x01(\x0b\x32;.device.heat_pump.config.v1.ccv.v1.PiecewiseLinearCoolCurveB\n\n\x08_enabledB\x10\n\x0e_room_setpointB\x1a\n\x18_minimum_supply_setpointB\x1a\n\x18_maximum_supply_setpoint\"\xe9\x03\n\x0cZoneSettings\x12G\n\x07heating\x18\x03 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneHeatingSettings\x12G\n\x07\x63ooling\x18\x04 \x01(\x0b\x32\x36.device.heat_pump.config.v1.ccv.v1.ZoneCoolingSettings\x12I\n\x11room_pi_regulator\x18\x05 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulator\x12H\n\x0cmixing_valve\x18\x07 \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.ZoneMixingValve\x12+\n\x1a\x64\x65precated_control_enabled\x18\x01 \x01(\x08\x42\x02\x18\x01H\x00\x88\x01\x01\x12`\n$deprecated_mixing_valve_pi_regulator\x18\x06 \x01(\x0b\x32..device.heat_pump.config.v1.ccv.v1.PiRegulatorB\x02\x18\x01\x42\x1d\n\x1b_deprecated_control_enabledJ\x04\x08\x02\x10\x03\"\xa2\x01\n\x08\x41wayMode\x12(\n\x1b\x64hw_tank_temperature_change\x18\x02 \x01(\x02H\x00\x88\x01\x01\x12$\n\x17room_temperature_change\x18\x03 \x01(\x02H\x01\x88\x01\x01\x42\x1e\n\x1c_dhw_tank_temperature_changeB\x1a\n\x18_room_temperature_changeJ\x04\x08\x01\x10\x02J\x04\x08\x04\x10\x05\"\xb4\x06\n\x0eHeatingCooling\x12\x16\n\tnum_zones\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x37\n*ambient_temperature_to_enable_heating_mode\x18\x03 \x01(\x02H\x01\x88\x01\x01\x12\x37\n*ambient_temperature_to_enable_cooling_mode\x18\x04 \x01(\x02H\x02\x88\x01\x01\x12\x30\n#minimum_time_heating_cooling_switch\x18\x06 \x01(\x05H\x03\x88\x01\x01\x12\x38\n+supply_temperature_too_high_alarm_temp_diff\x18\x07 \x01(\x02H\x04\x88\x01\x01\x12\x34\n\'supply_temperature_too_high_alarm_delay\x18\x08 \x01(\x05H\x05\x88\x01\x01\x12H\n\x0fsettings_zone_1\x18\t \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12H\n\x0fsettings_zone_2\x18\n \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.ZoneSettings\x12\x37\n*ambient_temperature_to_allow_inline_heater\x18\x0b \x01(\x02H\x06\x88\x01\x01\x42\x0c\n\n_num_zonesB-\n+_ambient_temperature_to_enable_heating_modeB-\n+_ambient_temperature_to_enable_cooling_modeB&\n$_minimum_time_heating_cooling_switchB.\n,_supply_temperature_too_high_alarm_temp_diffB*\n(_supply_temperature_too_high_alarm_delayB-\n+_ambient_temperature_to_allow_inline_heaterJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\"\xdd\x01\n\x11PumpSpeedSettings\x12\x14\n\x07heating\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07\x63ooling\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12\x14\n\x07\x64\x65\x66rost\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x14\n\x07minimum\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x17\n\nlegionella\x18\x05 \x01(\x05H\x04\x88\x01\x01\x12\x10\n\x03\x64hw\x18\x06 \x01(\x05H\x05\x88\x01\x01\x42\n\n\x08_heatingB\n\n\x08_coolingB\n\n\x08_defrostB\n\n\x08_minimumB\r\n\x0b_legionellaB\x06\n\x04_dhw\"\xc7\x01\n\x0f\x41larmThresholds\x12\"\n\x15\x66low_level_1_low_12kw\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12!\n\x14\x66low_level_1_low_8kw\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12!\n\x14\x66low_level_1_low_6kw\x18\x03 \x01(\x02H\x02\x88\x01\x01\x42\x18\n\x16_flow_level_1_low_12kwB\x17\n\x15_flow_level_1_low_8kwB\x17\n\x15_flow_level_1_low_6kw\"\x90\x02\n\x10\x45lectricityMeter\x12V\n\x04type\x18\x01 \x01(\x0e\x32H.device.heat_pump.config.v1.ccv.v1.ElectricityMeter.ElectricityMeterType\"\xa3\x01\n\x14\x45lectricityMeterType\x12&\n\"ELECTRICITY_METER_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x45LECTRICITY_METER_TYPE_NONE\x10\x01\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET340\x10\x02\x12 \n\x1c\x45LECTRICITY_METER_TYPE_ET112\x10\x03\"\xa4\x03\n\x0cInlineHeater\x12Q\n\x06step_1\x18\x01 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12Q\n\x06step_2\x18\x02 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\x12Q\n\x06step_3\x18\x03 \x01(\x0e\x32\x41.device.heat_pump.config.v1.ccv.v1.InlineHeater.InlineHeaterUsage\"\x9a\x01\n\x11InlineHeaterUsage\x12#\n\x1fINLINE_HEATER_USAGE_UNSPECIFIED\x10\x00\x12 \n\x1cINLINE_HEATER_USAGE_DISABLED\x10\x01\x12\x1e\n\x1aINLINE_HEATER_USAGE_BACKUP\x10\x02\x12\x1e\n\x1aINLINE_HEATER_USAGE_NORMAL\x10\x03\"-\n\tNightMode\x12\x14\n\x07\x65nabled\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_enabled\"\xc9\x03\n\nFlowMeters\x12Q\n\x0cmeter_1_type\x18\x01 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\x12Q\n\x0cmeter_2_type\x18\x02 \x01(\x0e\x32;.device.heat_pump.config.v1.ccv.v1.FlowMeters.FlowMeterType\"\x94\x02\n\rFlowMeterType\x12\x1f\n\x1b\x46LOW_METER_TYPE_UNSPECIFIED\x10\x00\x12!\n\x1d\x46LOW_METER_TYPE_NOT_CONNECTED\x10\x01\x12$\n FLOW_METER_TYPE_HUBA_DN20_BRONZE\x10\x02\x12$\n FLOW_METER_TYPE_HUBA_DN25_BRONZE\x10\x03\x12%\n!FLOW_METER_TYPE_HUBA_DN20_PLASTIC\x10\x04\x12%\n!FLOW_METER_TYPE_HUBA_DN25_PLASTIC\x10\x05\x12%\n!FLOW_METER_TYPE_HUBA_DN10_PLASTIC\x10\x06\"\xc3\x01\n\x11\x45nergyBalanceKick\x12\x1f\n\x12time_between_kicks\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13kick_temperature_up\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\"\n\x15kick_temperature_down\x18\x03 \x01(\x02H\x02\x88\x01\x01\x42\x15\n\x13_time_between_kicksB\x16\n\x14_kick_temperature_upB\x18\n\x16_kick_temperature_down\"\xb8\t\n\tCcvConfig\x12H\n\x0esensor_sources\x18\x01 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.SensorSources\x12R\n\x13\x63ompressor_settings\x18\x02 \x01(\x0b\x32\x35.device.heat_pump.config.v1.ccv.v1.CompressorSettings\x12H\n\x0eheating_system\x18\x07 \x01(\x0b\x32\x30.device.heat_pump.config.v1.ccv.v1.HeatingSystem\x12@\n\ndhw_system\x18\x08 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.DhwSystem\x12>\n\taway_mode\x18\t \x01(\x0b\x32+.device.heat_pump.config.v1.ccv.v1.AwayMode\x12J\n\x0fheating_cooling\x18\n \x01(\x0b\x32\x31.device.heat_pump.config.v1.ccv.v1.HeatingCooling\x12M\n\x11outdoor_unit_size\x18\r \x01(\x0e\x32\x32.device.heat_pump.config.v1.ccv.v1.OutdoorUnitSize\x12Q\n\x13pump_speed_settings\x18\x0e \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.PumpSpeedSettings\x12L\n\x10\x61larm_thresholds\x18\x0f \x01(\x0b\x32\x32.device.heat_pump.config.v1.ccv.v1.AlarmThresholds\x12N\n\x11\x65lectricity_meter\x18\x10 \x01(\x0b\x32\x33.device.heat_pump.config.v1.ccv.v1.ElectricityMeter\x12\x46\n\rinline_heater\x18\x11 \x01(\x0b\x32/.device.heat_pump.config.v1.ccv.v1.InlineHeater\x12@\n\nnight_mode\x18\x12 \x01(\x0b\x32,.device.heat_pump.config.v1.ccv.v1.NightMode\x12\x42\n\x0b\x66low_meters\x18\x13 \x01(\x0b\x32-.device.heat_pump.config.v1.ccv.v1.FlowMeters\x12Q\n\x13\x65nergy_balance_kick\x18\x14 \x01(\x0b\x32\x34.device.heat_pump.config.v1.ccv.v1.EnergyBalanceKickJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\x03\x10\x04J\x04\x08\x06\x10\x07R\x1c\x64\x65precated_ccv_serial_numberR\x16\x64\x65precated_ccv_versionR!deprecated_external_sensor_valuesR\x17\x64\x65precated_heating_mode*\x95\x01\n\x0fOutdoorUnitSize\x12!\n\x1dOUTDOOR_UNIT_SIZE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_6KW\x10\x01\x12\x1e\n\x1aOUTDOOR_UNIT_SIZE_AIRA_8KW\x10\x02\x12\x1f\n\x1bOUTDOOR_UNIT_SIZE_AIRA_12KW\x10\x03\x42\xec\x01\n3com.aira.contract.device.heat_pump.config.v1.ccv.v1B\x0e\x43\x63vConfigProtoP\x01\xa2\x02\x05\x44HCVC\xaa\x02 Device.HeatPump.Config.V1.Ccv.V1\xca\x02 Device\\HeatPump\\Config\\V1\\Ccv\\V1\xe2\x02,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\xea\x02%Device::HeatPump::Config::V1::Ccv::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.config.v1.ccv.v1.ccv_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n3com.aira.contract.device.heat_pump.config.v1.ccv.v1B\016CcvConfigProtoP\001\242\002\005DHCVC\252\002 Device.HeatPump.Config.V1.Ccv.V1\312\002 Device\\HeatPump\\Config\\V1\\Ccv\\V1\342\002,Device\\HeatPump\\Config\\V1\\Ccv\\V1\\GPBMetadata\352\002%Device::HeatPump::Config::V1::Ccv::V1'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_speed_level']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_working_mode']._serialized_options = b'\030\001'
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._loaded_options = None
  _globals['_COMPRESSORSETTINGS'].fields_by_name['deprecated_compressor_limit_time']._serialized_options = b'\030\001'
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._loaded_options = None
  _globals['_DOMESTICHOTWATERBOOST'].fields_by_name['deprecated_remaining_boost_time']._serialized_options = b'\030\001'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_control_enabled']._serialized_options = b'\030\001'
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._loaded_options = None
  _globals['_ZONESETTINGS'].fields_by_name['deprecated_mixing_valve_pi_regulator']._serialized_options = b'\030\001'
  _globals['_OUTDOORUNITSIZE']._serialized_start=9695
  _globals['_OUTDOORUNITSIZE']._serialized_end=9844
  _globals['_SENSORSOURCES']._serialized_start=142
  _globals['_SENSORSOURCES']._serialized_end=1167
  _globals['_COMPRESSORSETTINGS']._serialized_start=1170
  _globals['_COMPRESSORSETTINGS']._serialized_end=2456
  _globals['_DOMESTICHOTWATERBOOST']._serialized_start=2459
  _globals['_DOMESTICHOTWATERBOOST']._serialized_end=2632
  _globals['_PIREGULATOR']._serialized_start=2634
  _globals['_PIREGULATOR']._serialized_end=2719
  _globals['_HEATINGSYSTEM']._serialized_start=2722
  _globals['_HEATINGSYSTEM']._serialized_end=3232
  _globals['_LEGIONELLASETTINGS']._serialized_start=3235
  _globals['_LEGIONELLASETTINGS']._serialized_end=3557
  _globals['_DHWSYSTEM']._serialized_start=3560
  _globals['_DHWSYSTEM']._serialized_end=4182
  _globals['_ZONEMIXINGVALVE']._serialized_start=4185
  _globals['_ZONEMIXINGVALVE']._serialized_end=4538
  _globals['_ZONEHEATINGSETTINGS']._serialized_start=4541
  _globals['_ZONEHEATINGSETTINGS']._serialized_end=4855
  _globals['_ZONECOOLINGSETTINGS']._serialized_start=4858
  _globals['_ZONECOOLINGSETTINGS']._serialized_end=5172
  _globals['_ZONESETTINGS']._serialized_start=5175
  _globals['_ZONESETTINGS']._serialized_end=5664
  _globals['_AWAYMODE']._serialized_start=5667
  _globals['_AWAYMODE']._serialized_end=5829
  _globals['_HEATINGCOOLING']._serialized_start=5832
  _globals['_HEATINGCOOLING']._serialized_end=6652
  _globals['_PUMPSPEEDSETTINGS']._serialized_start=6655
  _globals['_PUMPSPEEDSETTINGS']._serialized_end=6876
  _globals['_ALARMTHRESHOLDS']._serialized_start=6879
  _globals['_ALARMTHRESHOLDS']._serialized_end=7078
  _globals['_ELECTRICITYMETER']._serialized_start=7081
  _globals['_ELECTRICITYMETER']._serialized_end=7353
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_start=7190
  _globals['_ELECTRICITYMETER_ELECTRICITYMETERTYPE']._serialized_end=7353
  _globals['_INLINEHEATER']._serialized_start=7356
  _globals['_INLINEHEATER']._serialized_end=7776
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_start=7622
  _globals['_INLINEHEATER_INLINEHEATERUSAGE']._serialized_end=7776
  _globals['_NIGHTMODE']._serialized_start=7778
  _globals['_NIGHTMODE']._serialized_end=7823
  _globals['_FLOWMETERS']._serialized_start=7826
  _globals['_FLOWMETERS']._serialized_end=8283
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_start=8007
  _globals['_FLOWMETERS_FLOWMETERTYPE']._serialized_end=8283
  _globals['_ENERGYBALANCEKICK']._serialized_start=8286
  _globals['_ENERGYBALANCEKICK']._serialized_end=8481
  _globals['_CCVCONFIG']._serialized_start=8484
  _globals['_CCVCONFIG']._serialized_end=9692
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v2/notification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'notification/v2/notification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"notification/v2/notification.proto\x12\x0fnotification.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12util/v2/uuid.proto\"\xac\x03\n\x0cNotification\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04read\x18\x05 \x01(\x08\x12<\n\x11notification_type\x18\x06 \x01(\x0e\x32!.notification.v2.NotificationType\x12)\n\x07subject\x18\x07 \x01(\x0e\x32\x18.notification.v2.Subject\x12:\n\x07\x63ontent\x18\x08 \x01(\x0b\x32$.notification.v2.NotificationContentH\x00\x88\x01\x01\x12\x38\n\x06\x61\x63tion\x18\t \x01(\x0b\x32#.notification.v2.NotificationActionH\x01\x88\x01\x01\x12\x1c\n\x0fmin_app_version\x18\n \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_contentB\t\n\x07_actionB\x12\n\x10_min_app_version\"A\n\x15\x43ommunicationChannels\x12\x0b\n\x03sms\x18\x01 \x01(\x08\x12\x0c\n\x04push\x18\x02 \x01(\x08\x12\r\n\x05\x65mail\x18\x03 \x01(\x08\"2\n\x13NotificationContent\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\"i\n\x12NotificationAction\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.notification.v2.NotificationActionType\x12\r\n\x05value\x18\x02 \x01(\t\x12\r\n\x05label\x18\x03 \x01(\t*i\n\x07Subject\x12\x17\n\x13SUBJECT_UNSPECIFIED\x10\x00\x12\x15\n\x11SUBJECT_HEAT_PUMP\x10\x01\x12\x16\n\x12SUBJECT_INVITATION\x10\x02\x12\x16\n\x12SUBJECT_THERMOSTAT\x10\x03*\x8d\x01\n\x10NotificationType\x12!\n\x1dNOTIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16NOTIFICATION_TYPE_INFO\x10\x01\x12\x1b\n\x17NOTIFICATION_TYPE_ERROR\x10\x02\x12\x1d\n\x19NOTIFICATION_TYPE_WARNING\x10\x03*\x88\x01\n\x16NotificationActionType\x12(\n$NOTIFICATION_ACTION_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1cNOTIFICATION_ACTION_TYPE_URL\x10\x01\x12\"\n\x1eNOTIFICATION_ACTION_TYPE_ROUTE\x10\x02\x42\x93\x01\n!com.aira.contract.notification.v2B\x11NotificationProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V2\xca\x02\x0fNotification\\V2\xe2\x02\x1bNotification\\V2\\GPBMetadata\xea\x02\x10Notification::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v2.notification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.notification.v2B\021NotificationProtoP\001\242\002\003NXX\252\002\017Notification.V2\312\002\017Notification\\V2\342\002\033Notification\\V2\\GPBMetadata\352\002\020Notification::V2'
  _globals['_SUBJECT']._serialized_start=765
  _globals['_SUBJECT']._serialized_end=870
  _globals['_NOTIFICATIONTYPE']._serialized_start=873
  _globals['_NOTIFICATIONTYPE']._serialized_end=1014
  _globals['_NOTIFICATIONACTIONTYPE']._serialized_start=1017
  _globals['_NOTIFICATIONACTIONTYPE']._serialized_end=1153
  _globals['_NOTIFICATION']._serialized_start=109
  _globals['_NOTIFICATION']._serialized_end=537
  _globals['_COMMUNICATIONCHANNELS']._serialized_start=539
  _globals['_COMMUNICATIONCHANNELS']._serialized_end=604
  _globals['_NOTIFICATIONCONTENT']._serialized_start=606
  _globals['_NOTIFICATIONCONTENT']._serialized_end=656
  _globals['_NOTIFICATIONACTION']._serialized_start=658
  _globals['_NOTIFICATIONACTION']._serialized_end=763
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/heat_pump/modbus/v1/exception.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/heat_pump/modbus/v1/exception.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*device/heat_pump/modbus/v1/exception.proto\x12\x1a\x64\x65vice.heat_pump.modbus.v1*\xde\x02\n\tException\x12\x19\n\x15\x45XCEPTION_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x45XCEPTION_ILLEGAL_FUNCTION\x10\x01\x12\"\n\x1e\x45XCEPTION_ILLEGAL_DATA_ADDRESS\x10\x02\x12 \n\x1c\x45XCEPTION_ILLEGAL_DATA_VALUE\x10\x03\x12#\n\x1f\x45XCEPTION_SERVER_DEVICE_FAILURE\x10\x04\x12\x19\n\x15\x45XCEPTION_ACKNOWLEDGE\x10\x05\x12 \n\x1c\x45XCEPTION_SERVER_DEVICE_BUSY\x10\x06\x12!\n\x1d\x45XCEPTION_MEMORY_PARITY_ERROR\x10\x08\x12&\n\"EXCEPTION_GATEWAY_PATH_UNAVAILABLE\x10\n\x12#\n\x1f\x45XCEPTION_GATEWAY_TARGET_DEVICE\x10\x0b\x42\xc5\x01\n,com.aira.contract.device.heat_pump.modbus.v1B\x0e\x45xceptionProtoP\x01\xa2\x02\x03\x44HM\xaa\x02\x19\x44\x65vice.HeatPump.Modbus.V1\xca\x02\x19\x44\x65vice\\HeatPump\\Modbus\\V1\xe2\x02%Device\\HeatPump\\Modbus\\V1\\GPBMetadata\xea\x02\x1c\x44\x65vice::HeatPump::Modbus::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.heat_pump.modbus.v1.exception_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,com.aira.contract.device.heat_pump.modbus.v1B\016ExceptionProtoP\001\242\002\003DHM\252\002\031Device.HeatPump.Modbus.V1\312\002\031Device\\HeatPump\\Modbus\\V1\342\002%Device\\HeatPump\\Modbus\\V1\\GPBMetadata\352\002\034Device::HeatPump::Modbus::V1'
  _globals['_EXCEPTION']._serialized_start=75
  _globals['_EXCEPTION']._serialized_end=425
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: notification/v1/notification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'notification/v1/notification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"notification/v1/notification.proto\x12\x0fnotification.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x12util/v1/uuid.proto\"\xfb\x01\n\x0cNotification\x12\x1d\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.UuidB\x02\x18\x01\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04read\x18\x05 \x01(\x08\x12<\n\x11notification_type\x18\x06 \x01(\x0e\x32!.notification.v1.NotificationType\x12)\n\x07subject\x18\x07 \x01(\x0e\x32\x18.notification.v1.Subject:\x02\x18\x01J\x04\x08\x08\x10\t\"<\n\x15\x43ommunicationChannels\x12\x0b\n\x03sms\x18\x02 \x01(\x08\x12\x0c\n\x04push\x18\x03 \x01(\x08:\x02\x18\x01J\x04\x08\x01\x10\x02*=\n\x07Subject\x12\x17\n\x13SUBJECT_UNSPECIFIED\x10\x00\x12\x15\n\x11SUBJECT_HEAT_PUMP\x10\x01\x1a\x02\x18\x01*x\n\x10NotificationType\x12!\n\x1dNOTIFICATION_TYPE_UNSPECIFIED\x10\x00\x12\x1a\n\x16NOTIFICATION_TYPE_INFO\x10\x01\x12\x1b\n\x17NOTIFICATION_TYPE_ERROR\x10\x02\x1a\x02\x18\x01\"\x04\x08\x03\x10\x03\x42\x93\x01\n!com.aira.contract.notification.v1B\x11NotificationProtoP\x01\xa2\x02\x03NXX\xaa\x02\x0fNotification.V1\xca\x02\x0fNotification\\V1\xe2\x02\x1bNotification\\V1\\GPBMetadata\xea\x02\x10Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'notification.v1.notification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.notification.v1B\021NotificationProtoP\001\242\002\003NXX\252\002\017Notification.V1\312\002\017Notification\\V1\342\002\033Notification\\V1\\GPBMetadata\352\002\020Notification::V1'
  _globals['_SUBJECT']._loaded_options = None
  _globals['_SUBJECT']._serialized_options = b'\030\001'
  _globals['_NOTIFICATIONTYPE']._loaded_options = None
  _globals['_NOTIFICATIONTYPE']._serialized_options = b'\030\001'
  _globals['_NOTIFICATION'].fields_by_name['id']._loaded_options = None
  _globals['_NOTIFICATION'].fields_by_name['id']._serialized_options = b'\030\001'
  _globals['_NOTIFICATION']._loaded_options = None
  _globals['_NOTIFICATION']._serialized_options = b'\030\001'
  _globals['_COMMUNICATIONCHANNELS']._loaded_options = None
  _globals['_COMMUNICATIONCHANNELS']._serialized_options = b'\030\001'
  _globals['_SUBJECT']._serialized_start=424
  _globals['_SUBJECT']._serialized_end=485
  _globals['_NOTIFICATIONTYPE']._serialized_start=487
  _globals['_NOTIFICATIONTYPE']._serialized_end=607
  _globals['_NOTIFICATION']._serialized_start=109
  _globals['_NOTIFICATION']._serialized_end=360
  _globals['_COMMUNICATIONCHANNELS']._serialized_start=362
  _globals['_COMMUNICATIONCHANNELS']._serialized_end=422
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: device/v1/devices.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'device/v1/devices.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..heat_pump.state.v1 import state_pb2 as device_dot_heat__pump_dot_state_dot_v1_dot_state__pb2
from ..heat_pump.util.v1 import water_tank_size_pb2 as device_dot_heat__pump_dot_util_dot_v1_dot_water__tank__size__pb2
from . import certificate_pb2 as device_dot_v1_dot_certificate__pb2
from . import online_pb2 as device_dot_v1_dot_online__pb2
from ...util.v1 import uuid_pb2 as util_dot_v1_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x64\x65vice/v1/devices.proto\x12\tdevice.v1\x1a%device/heat_pump/state/v1/state.proto\x1a.device/heat_pump/util/v1/water_tank_size.proto\x1a\x1b\x64\x65vice/v1/certificate.proto\x1a\x16\x64\x65vice/v1/online.proto\x1a\x12util/v1/uuid.proto\"\xa9\x02\n\x08HeatPump\x12+\n\x0b\x63\x65rtificate\x18\x01 \x01(\x0b\x32\x16.device.v1.Certificate\x12\x19\n\x02id\x18\x03 \x01(\x0b\x32\r.util.v1.Uuid\x12\x35\n\x14\x64\x65precated_tank_size\x18\x04 \x01(\x0e\x32\x13.device.v1.TankSizeB\x02\x18\x01\x12:\n\ttank_size\x18\x08 \x01(\x0e\x32\'.device.heat_pump.util.v1.WaterTankSize\x12\x1a\n\x12night_mode_enabled\x18\x07 \x01(\x08J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x02\x10\x03R\x13heating_zone_1_nameR\x13heating_zone_2_nameR\nthread_key\"X\n\x06\x44\x65vice\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\x12!\n\x06online\x18\x04 \x01(\x0b\x32\x11.device.v1.OnlineJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06\"=\n\x11GetDevicesRequest\x12(\n\rheat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.UuidB\x02\x18\x01\"8\n\x12GetDevicesResponse\x12\"\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x11.device.v1.Device\"4\n\x17GetDeviceDetailsRequest\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v1.Uuid\"L\n\x18GetDeviceDetailsResponse\x12(\n\theat_pump\x18\x01 \x01(\x0b\x32\x13.device.v1.HeatPumpH\x00\x42\x06\n\x04type\"N\n\x1a\x43reateDeviceDetailsRequest\x12(\n\theat_pump\x18\x01 \x01(\x0b\x32\x13.device.v1.HeatPumpH\x00\x42\x06\n\x04type\"\x1d\n\x1b\x43reateDeviceDetailsResponse\"\x16\n\x14StreamDevicesRequest\";\n\x15StreamDevicesResponse\x12\"\n\x07\x64\x65vices\x18\x01 \x03(\x0b\x32\x11.device.v1.Device\"8\n\x10GetStatesRequest\x12$\n\rheat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.Uuid\"O\n\x11GetStatesResponse\x12:\n\x10heat_pump_states\x18\x01 \x03(\x0b\x32 .device.heat_pump.state.v1.State\";\n\x13StreamStatesRequest\x12$\n\rheat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v1.Uuid\"R\n\x14StreamStatesResponse\x12:\n\x10heat_pump_states\x18\x01 \x03(\x0b\x32 .device.heat_pump.state.v1.State*Y\n\x08TankSize\x12\x19\n\x15TANK_SIZE_UNSPECIFIED\x10\x00\x12\x18\n\x14TANK_SIZE_100_LITERS\x10\x01\x12\x18\n\x14TANK_SIZE_250_LITERS\x10\x02\x32\x8f\x04\n\x0e\x44\x65vicesService\x12I\n\nGetDevices\x12\x1c.device.v1.GetDevicesRequest\x1a\x1d.device.v1.GetDevicesResponse\x12[\n\x10GetDeviceDetails\x12\".device.v1.GetDeviceDetailsRequest\x1a#.device.v1.GetDeviceDetailsResponse\x12\x64\n\x13\x43reateDeviceDetails\x12%.device.v1.CreateDeviceDetailsRequest\x1a&.device.v1.CreateDeviceDetailsResponse\x12T\n\rStreamDevices\x12\x1f.device.v1.StreamDevicesRequest\x1a .device.v1.StreamDevicesResponse0\x01\x12\x46\n\tGetStates\x12\x1b.device.v1.GetStatesRequest\x1a\x1c.device.v1.GetStatesResponse\x12Q\n\x0cStreamStates\x12\x1e.device.v1.StreamStatesRequest\x1a\x1f.device.v1.StreamStatesResponse0\x01\x42p\n\x1b\x63om.aira.contract.device.v1B\x0c\x44\x65vicesProtoP\x01\xa2\x02\x03\x44XX\xaa\x02\tDevice.V1\xca\x02\tDevice\\V1\xe2\x02\x15\x44\x65vice\\V1\\GPBMetadata\xea\x02\nDevice::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device.v1.devices_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.aira.contract.device.v1B\014DevicesProtoP\001\242\002\003DXX\252\002\tDevice.V1\312\002\tDevice\\V1\342\002\025Device\\V1\\GPBMetadata\352\002\nDevice::V1'
  _globals['_HEATPUMP'].fields_by_name['deprecated_tank_size']._loaded_options = None
  _globals['_HEATPUMP'].fields_by_name['deprecated_tank_size']._serialized_options = b'\030\001'
  _globals['_GETDEVICESREQUEST'].fields_by_name['heat_pump_ids']._loaded_options = None
  _globals['_GETDEVICESREQUEST'].fields_by_name['heat_pump_ids']._serialized_options = b'\030\001'
  _globals['_TANKSIZE']._serialized_start=1321
  _globals['_TANKSIZE']._serialized_end=1410
  _globals['_HEATPUMP']._serialized_start=199
  _globals['_HEATPUMP']._serialized_end=496
  _globals['_DEVICE']._serialized_start=498
  _globals['_DEVICE']._serialized_end=586
  _globals['_GETDEVICESREQUEST']._serialized_start=588
  _globals['_GETDEVICESREQUEST']._serialized_end=649
  _globals['_GETDEVICESRESPONSE']._serialized_start=651
  _globals['_GETDEVICESRESPONSE']._serialized_end=707
  _globals['_GETDEVICEDETAILSREQUEST']._serialized_start=709
  _globals['_GETDEVICEDETAILSREQUEST']._serialized_end=761
  _globals['_GETDEVICEDETAILSRESPONSE']._serialized_start=763
  _globals['_GETDEVICEDETAILSRESPONSE']._serialized_end=839
  _globals['_CREATEDEVICEDETAILSREQUEST']._serialized_start=841
  _globals['_CREATEDEVICEDETAILSREQUEST']._serialized_end=919
  _globals['_CREATEDEVICEDETAILSRESPONSE']._serialized_start=921
  _globals['_CREATEDEVICEDETAILSRESPONSE']._serialized_end=950
  _globals['_STREAMDEVICESREQUEST']._serialized_start=952
  _globals['_STREAMDEVICESREQUEST']._serialized_end=974
  _globals['_STREAMDEVICESRESPONSE']._serialized_start=976
  _globals['_STREAMDEVICESRESPONSE']._serialized_end=1035
  _globals['_GETSTATESREQUEST']._serialized_start=1037
  _globals['_GETSTATESREQUEST']._serialized_end=1093
  _globals['_GETSTATESRESPONSE']._serialized_start=1095
  _globals['_GETSTATESRESPONSE']._serialized_end=1174
  _globals['_STREAMSTATESREQUEST']._serialized_start=1176
  _globals['_STREAMSTATESREQUEST']._serialized_end=1235
  _globals['_STREAMSTATESRESPONSE']._serialized_start=1237
  _globals['_STREAMSTATESRESPONSE']._serialized_end=1319
  _globals['_DEVICESSERVICE']._serialized_start=1413
  _globals['_DEVICESSERVICE']._serialized_end=1940
# @@protoc_insertion_point(module_scope)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: user_account/v2/user_account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'user_account/v2/user_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...notification.v2 import notification_pb2 as notification_dot_v2_dot_notification__pb2
from . import role_pb2 as user__account_dot_v2_dot_role__pb2
from ...util.v2 import locale_pb2 as util_dot_v2_dot_locale__pb2
from ...util.v2 import market_pb2 as util_dot_v2_dot_market__pb2
from ...util.v2 import uuid_pb2 as util_dot_v2_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"user_account/v2/user_account.proto\x12\x0fuser_account.v2\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\"notification/v2/notification.proto\x1a\x1auser_account/v2/role.proto\x1a\x14util/v2/locale.proto\x1a\x14util/v2/market.proto\x1a\x12util/v2/uuid.proto\"B\n\x1bGetHeatPumpZoneNamesRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"N\n\x1cGetHeatPumpZoneNamesResponse\x12.\n\nzone_names\x18\x01 \x01(\x0b\x32\x1a.user_account.v2.ZoneNames\"+\n\tZoneNames\x12\x0e\n\x06zone_1\x18\x01 \x01(\t\x12\x0e\n\x06zone_2\x18\x02 \x01(\t\"\x90\x01\n\x19\x43onfirmEmailChangeRequest\x12#\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.UuidH\x00\x88\x01\x01\x12\x11\n\tnew_email\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\tB\n\n\x08_user_id\"\x1c\n\x1a\x43onfirmEmailChangeResponse\"\x82\x01\n\x19\x43onfirmPhoneNumberRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x03 \x01(\t\x12\x19\n\x11\x63onfirmation_code\x18\x04 \x01(\t\"\x1c\n\x1a\x43onfirmPhoneNumberResponse\"D\n!GetFeaturesAsNotificationsRequest\x12\x1f\n\x06locale\x18\x01 \x01(\x0e\x32\x0f.util.v2.Locale\"Z\n\"GetFeaturesAsNotificationsResponse\x12\x34\n\rnotifications\x18\x01 \x03(\x0b\x32\x1d.notification.v2.Notification\"k\n\x12HeatPumpPermission\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x30\n\x0bpermissions\x18\x02 \x03(\x0e\x32\x1b.user_account.v2.Permission\"\x83\x01\n\x1d\x41\x64\x64HeatPumpPermissionsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x42\n\x15heat_pump_permissions\x18\x02 \x03(\x0b\x32#.user_account.v2.HeatPumpPermission\" \n\x1e\x41\x64\x64HeatPumpPermissionsResponse\"\x9c\x03\n\x0bUserAccount\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12!\n\ncontact_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x08 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\t \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\n \x01(\x08\x12!\n\ncognito_id\x18\x0b \x01(\x0b\x32\r.util.v2.Uuid\x12\x1e\n\x16phone_number_confirmed\x18\x0c \x01(\x08\x12S\n\x1dproximity_verification_status\x18\r \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatusJ\x04\x08\x07\x10\x08\"\x84\x02\n\x10InstallerAccount\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12!\n\ncognito_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x08 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\t \x01(\x0e\x32\x0f.util.v2.Market\x12\x1d\n\x15is_external_installer\x18\n \x01(\x08\"E\n GetUserAccountByCognitoIdRequest\x12!\n\ncognito_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"\x8d\x01\n!GetUserAccountByCognitoIdResponse\x12\x32\n\x0cuser_account\x18\x02 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\x12.\n\nhouseholds\x18\x03 \x03(\x0b\x32\x1a.user_account.v2.HouseholdJ\x04\x08\x01\x10\x02\"?\n\x1dGetUserAccountByUserIdRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"T\n\x1eGetUserAccountByUserIdResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"E\n GetUserAccountByContactIdRequest\x12!\n\ncontact_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"]\n!GetUserAccountByContactIdResponse\x12\x32\n\x0cuser_account\x18\x02 \x01(\x0b\x32\x1c.user_account.v2.UserAccountJ\x04\x08\x01\x10\x02\"\x8e\x02\n\x18\x43reateUserAccountRequest\x12!\n\ncontact_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12\x14\n\x0cphone_number\x18\x03 \x01(\t\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\x1f\n\x06locale\x18\x06 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x07 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\x08 \x01(\x08\x12!\n\ncognito_id\x18\t \x01(\x0b\x32\r.util.v2.Uuid\"O\n\x19\x43reateUserAccountResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"\x82\x02\n\x18UpdateUserAccountRequest\x12\x1e\n\x07user_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12!\n\ncontact_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1c\n\x14notification_enabled\x18\t \x01(\x08J\x04\x08\x01\x10\x02\"O\n\x19UpdateUserAccountResponse\x12\x32\n\x0cuser_account\x18\x01 \x01(\x0b\x32\x1c.user_account.v2.UserAccount\"\xc3\x01\n\rLegalDocument\x12\"\n\x0b\x64ocument_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x39\n\rdocument_type\x18\x03 \x01(\x0e\x32\".user_account.v2.LegalDocumentType\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x1f\n\x06market\x18\x05 \x01(\x0e\x32\x0f.util.v2.Market\x12\x10\n\x08web_link\x18\x06 \x01(\t\"\xa5\x01\n\x1aLegalDocumentUserAgreement\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12/\n\x0b\x61\x63\x63\x65pted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x0elegal_document\x18\x03 \x01(\x0b\x32\x1e.user_account.v2.LegalDocument\"=\n\x1bGetAllUserAgreementsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"_\n\x1cGetAllUserAgreementsResponse\x12?\n\nagreements\x18\x01 \x03(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"s\n\'CreateLegalDocumentUserAgreementRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12(\n\x11legal_document_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\"*\n(CreateLegalDocumentUserAgreementResponse\"L\n*UserHasAcceptedLatestLegalDocumentsRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"n\n+UserHasAcceptedLatestLegalDocumentsResponse\x12?\n\nagreements\x18\x01 \x03(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"b\n LegalDocumentUserAgreementEntity\x12>\n\tagreement\x18\x01 \x01(\x0b\x32+.user_account.v2.LegalDocumentUserAgreement\"\xd7\x03\n\x16\x41\x64minUpdateUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x12\n\x05\x65mail\x18\x02 \x01(\tH\x00\x88\x01\x01\x12#\n\x0cheat_pump_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x19\n\x0cphone_number\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x17\n\ngiven_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x66\x61mily_name\x18\x06 \x01(\tH\x03\x88\x01\x01\x12$\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.LocaleH\x04\x88\x01\x01\x12$\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.MarketH\x05\x88\x01\x01\x12N\n\x13verification_status\x18\n \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatusH\x06\x88\x01\x01\x42\x08\n\x06_emailB\x0f\n\r_phone_numberB\r\n\x0b_given_nameB\x0e\n\x0c_family_nameB\t\n\x07_localeB\t\n\x07_marketB\x16\n\x14_verification_statusJ\x04\x08\t\x10\nR\x0cis_installer\"\x19\n\x17\x41\x64minUpdateUserResponse\"\x81\x02\n\x16\x41\x64minCreateUserRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12#\n\x0cheat_pump_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x04 \x01(\t\x12\x12\n\ngiven_name\x18\x05 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x06 \x01(\t\x12\x1f\n\x06locale\x18\x07 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x08 \x01(\x0e\x32\x0f.util.v2.MarketJ\x04\x08\t\x10\nR\x0cis_installer\"\x19\n\x17\x41\x64minCreateUserResponse\"\xd3\x01\n\"AdminCreateInstallerAccountRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1f\n\x06locale\x18\x05 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x06 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1d\n\x15is_external_installer\x18\x07 \x01(\x08\"c\n#AdminCreateInstallerAccountResponse\x12<\n\x11installer_account\x18\x01 \x01(\x0b\x32!.user_account.v2.InstallerAccount\"\xe4\x01\n\"AdminUpdateInstallerAccountRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x14\n\x0cphone_number\x18\x02 \x01(\t\x12\x12\n\ngiven_name\x18\x03 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x04 \x01(\t\x12\x1f\n\x06locale\x18\x05 \x01(\x0e\x32\x0f.util.v2.Locale\x12\x1f\n\x06market\x18\x06 \x01(\x0e\x32\x0f.util.v2.Market\x12\x1d\n\x15is_external_installer\x18\x07 \x01(\x08\"c\n#AdminUpdateInstallerAccountResponse\x12<\n\x11installer_account\x18\x01 \x01(\x0b\x32!.user_account.v2.InstallerAccount\"T\n AdminFindInstallerAccountRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12!\n\ncognito_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\"a\n!AdminFindInstallerAccountResponse\x12<\n\x11installer_account\x18\x01 \x01(\x0b\x32!.user_account.v2.InstallerAccount\"I\n\"GetUserAccountsByHeatPumpIdRequest\x12#\n\x0cheat_pump_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\"Y\n#GetUserAccountsByHeatPumpIdResponse\x12\x32\n\x0cuser_account\x18\x01 \x03(\x0b\x32\x1c.user_account.v2.UserAccount\"M\n\x1cGetHouseholdsByUserIdRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\"S\n\x1dGetHouseholdsByUserIdResponse\x12.\n\nhouseholds\x18\x01 \x03(\x0b\x32\x1a.user_account.v2.Household:\x02\x18\x01\"\xb8\x01\n\tHousehold\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n\tresidents\x18\x03 \x03(\x0b\x32\x19.user_account.v2.Resident\x12,\n\theat_pump\x18\x04 \x01(\x0b\x32\x19.user_account.v2.HeatPump\x12\"\n\x0b\x66\x61\x63ility_id\x18\x05 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\")\n\x08HeatPump\x12\x19\n\x02id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\"\xbb\x01\n\x08Resident\x12)\n\x12\x65ngagement_user_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12#\n\x0chousehold_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid\x12\x12\n\ngiven_name\x18\x04 \x01(\t\x12\x13\n\x0b\x66\x61mily_name\x18\x05 \x01(\t\x12\r\n\x05\x65mail\x18\x06 \x01(\t\x12#\n\x04role\x18\x07 \x01(\x0e\x32\x15.user_account.v2.Role:\x02\x18\x01\"\xa1\x01\n\x15\x44\x65leteResidentRequest\x12)\n\x12\x65ngagement_user_id\x18\x01 \x01(\x0b\x32\r.util.v2.Uuid\x12#\n\x0chousehold_id\x18\x02 \x01(\x0b\x32\r.util.v2.Uuid\x12\x34\n\x1d\x64\x65leted_by_engagement_user_id\x18\x03 \x01(\x0b\x32\r.util.v2.Uuid:\x02\x18\x01\"\x1c\n\x16\x44\x65leteResidentResponse:\x02\x18\x01\"\'\n%GetProximityVerificationStatusRequest\"s\n&GetProximityVerificationStatusResponse\x12I\n\x13verification_status\x18\x01 \x01(\x0e\x32,.user_account.v2.ProximityVerificationStatus\"D\n\x16VerifyProximityRequest\x12*\n\x13\x63lose_heat_pump_ids\x18\x01 \x03(\x0b\x32\r.util.v2.Uuid\":\n\x17VerifyProximityResponse\x12\x1f\n\x17verification_successful\x18\x01 \x01(\x08*\x84\x01\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x13\n\x0fPERMISSION_READ\x10\x01\x12\x16\n\x12PERMISSION_CONTROL\x10\x02\x12\x17\n\x13PERMISSION_SCHEDULE\x10\x03\x12\x14\n\x10PERMISSION_SHARE\x10\x04*\x8a\x01\n\x11LegalDocumentType\x12#\n\x1fLEGAL_DOCUMENT_TYPE_UNSPECIFIED\x10\x00\x12(\n$LEGAL_DOCUMENT_TYPE_TERMS_OF_SERVICE\x10\x01\x12&\n\"LEGAL_DOCUMENT_TYPE_PRIVACY_POLICY\x10\x02*\xd6\x01\n\x1bProximityVerificationStatus\x12-\n)PROXIMITY_VERIFICATION_STATUS_UNSPECIFIED\x10\x00\x12.\n*PROXIMITY_VERIFICATION_STATUS_NOT_VERIFIED\x10\x01\x12*\n&PROXIMITY_VERIFICATION_STATUS_VERIFIED\x10\x02\x12,\n(PROXIMITY_VERIFICATION_STATUS_NOT_NEEDED\x10\x03\x32\xe4\x15\n\x12UserAccountService\x12y\n\x16\x41\x64\x64HeatPumpPermissions\x12..user_account.v2.AddHeatPumpPermissionsRequest\x1a/.user_account.v2.AddHeatPumpPermissionsResponse\x12m\n\x12\x43onfirmEmailChange\x12*.user_account.v2.ConfirmEmailChangeRequest\x1a+.user_account.v2.ConfirmEmailChangeResponse\x12m\n\x12\x43onfirmPhoneNumber\x12*.user_account.v2.ConfirmPhoneNumberRequest\x1a+.user_account.v2.ConfirmPhoneNumberResponse\x12\x82\x01\n\x19GetUserAccountByContactId\x12\x31.user_account.v2.GetUserAccountByContactIdRequest\x1a\x32.user_account.v2.GetUserAccountByContactIdResponse\x12\x82\x01\n\x19GetUserAccountByCognitoId\x12\x31.user_account.v2.GetUserAccountByCognitoIdRequest\x1a\x32.user_account.v2.GetUserAccountByCognitoIdResponse\x12y\n\x16GetUserAccountByUserId\x12..user_account.v2.GetUserAccountByUserIdRequest\x1a/.user_account.v2.GetUserAccountByUserIdResponse\x12j\n\x11\x43reateUserAccount\x12).user_account.v2.CreateUserAccountRequest\x1a*.user_account.v2.CreateUserAccountResponse\x12j\n\x11UpdateUserAccount\x12).user_account.v2.UpdateUserAccountRequest\x1a*.user_account.v2.UpdateUserAccountResponse\x12\x64\n\x0f\x41\x64minUpdateUser\x12\'.user_account.v2.AdminUpdateUserRequest\x1a(.user_account.v2.AdminUpdateUserResponse\x12\x88\x01\n\x1b\x41\x64minCreateInstallerAccount\x12\x33.user_account.v2.AdminCreateInstallerAccountRequest\x1a\x34.user_account.v2.AdminCreateInstallerAccountResponse\x12\x82\x01\n\x19\x41\x64minFindInstallerAccount\x12\x31.user_account.v2.AdminFindInstallerAccountRequest\x1a\x32.user_account.v2.AdminFindInstallerAccountResponse\x12\x88\x01\n\x1b\x41\x64minUpdateInstallerAccount\x12\x33.user_account.v2.AdminUpdateInstallerAccountRequest\x1a\x34.user_account.v2.AdminUpdateInstallerAccountResponse\x12s\n\x14GetAllUserAgreements\x12,.user_account.v2.GetAllUserAgreementsRequest\x1a-.user_account.v2.GetAllUserAgreementsResponse\x12\x97\x01\n CreateLegalDocumentUserAgreement\x12\x38.user_account.v2.CreateLegalDocumentUserAgreementRequest\x1a\x39.user_account.v2.CreateLegalDocumentUserAgreementResponse\x12\xa0\x01\n#UserHasAcceptedLatestLegalDocuments\x12;.user_account.v2.UserHasAcceptedLatestLegalDocumentsRequest\x1a<.user_account.v2.UserHasAcceptedLatestLegalDocumentsResponse\x12s\n\x14GetHeatPumpZoneNames\x12,.user_account.v2.GetHeatPumpZoneNamesRequest\x1a-.user_account.v2.GetHeatPumpZoneNamesResponse\x12\x88\x01\n\x1bGetUserAccountsByHeatPumpId\x12\x33.user_account.v2.GetUserAccountsByHeatPumpIdRequest\x1a\x34.user_account.v2.GetUserAccountsByHeatPumpIdResponse\x12{\n\x15GetHouseholdsByUserId\x12-.user_account.v2.GetHouseholdsByUserIdRequest\x1a..user_account.v2.GetHouseholdsByUserIdResponse\"\x03\x88\x02\x01\x12\x66\n\x0e\x44\x65leteResident\x12&.user_account.v2.DeleteResidentRequest\x1a\'.user_account.v2.DeleteResidentResponse\"\x03\x88\x02\x01\x12\x85\x01\n\x1aGetFeaturesAsNotifications\x12\x32.user_account.v2.GetFeaturesAsNotificationsRequest\x1a\x33.user_account.v2.GetFeaturesAsNotificationsResponse\x12\x91\x01\n\x1eGetProximityVerificationStatus\x12\x36.user_account.v2.GetProximityVerificationStatusRequest\x1a\x37.user_account.v2.GetProximityVerificationStatusResponse\x12\x64\n\x0fVerifyProximity\x12\'.user_account.v2.VerifyProximityRequest\x1a(.user_account.v2.VerifyProximityResponseB\x8e\x01\n!com.aira.contract.user_account.v2B\x10UserAccountProtoP\x01\xa2\x02\x03UXX\xaa\x02\x0eUserAccount.V2\xca\x02\x0eUserAccount\\V2\xe2\x02\x1aUserAccount\\V2\\GPBMetadata\xea\x02\x0fUserAccount::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_account.v2.user_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.aira.contract.user_account.v2B\020UserAccountProtoP\001\242\002\003UXX\252\002\016UserAccount.V2\312\002\016UserAccount\\V2\342\002\032UserAccount\\V2\\GPBMetadata\352\002\017UserAccount::V2'
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._loaded_options = None
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_options = b'\030\001'
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._loaded_options = None
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_options = b'\030\001'
  _globals['_HOUSEHOLD']._loaded_options = None
  _globals['_HOUSEHOLD']._serialized_options = b'\030\001'
  _globals['_HEATPUMP']._loaded_options = None
  _globals['_HEATPUMP']._serialized_options = b'\030\001'
  _globals['_RESIDENT']._loaded_options = None
  _globals['_RESIDENT']._serialized_options = b'\030\001'
  _globals['_DELETERESIDENTREQUEST']._loaded_options = None
  _globals['_DELETERESIDENTREQUEST']._serialized_options = b'\030\001'
  _globals['_DELETERESIDENTRESPONSE']._loaded_options = None
  _globals['_DELETERESIDENTRESPONSE']._serialized_options = b'\030\001'
  _globals['_USERACCOUNTSERVICE'].methods_by_name['GetHouseholdsByUserId']._loaded_options = None
  _globals['_USERACCOUNTSERVICE'].methods_by_name['GetHouseholdsByUserId']._serialized_options = b'\210\002\001'
  _globals['_USERACCOUNTSERVICE'].methods_by_name['DeleteResident']._loaded_options = None
  _globals['_USERACCOUNTSERVICE'].methods_by_name['DeleteResident']._serialized_options = b'\210\002\001'
  _globals['_PERMISSION']._serialized_start=6924
  _globals['_PERMISSION']._serialized_end=7056
  _globals['_LEGALDOCUMENTTYPE']._serialized_start=7059
  _globals['_LEGALDOCUMENTTYPE']._serialized_end=7197
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_start=7200
  _globals['_PROXIMITYVERIFICATIONSTATUS']._serialized_end=7414
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_start=216
  _globals['_GETHEATPUMPZONENAMESREQUEST']._serialized_end=282
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_start=284
  _globals['_GETHEATPUMPZONENAMESRESPONSE']._serialized_end=362
  _globals['_ZONENAMES']._serialized_start=364
  _globals['_ZONENAMES']._serialized_end=407
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_start=410
  _globals['_CONFIRMEMAILCHANGEREQUEST']._serialized_end=554
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_start=556
  _globals['_CONFIRMEMAILCHANGERESPONSE']._serialized_end=584
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_start=587
  _globals['_CONFIRMPHONENUMBERREQUEST']._serialized_end=717
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_start=719
  _globals['_CONFIRMPHONENUMBERRESPONSE']._serialized_end=747
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_start=749
  _globals['_GETFEATURESASNOTIFICATIONSREQUEST']._serialized_end=817
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_start=819
  _globals['_GETFEATURESASNOTIFICATIONSRESPONSE']._serialized_end=909
  _globals['_HEATPUMPPERMISSION']._serialized_start=911
  _globals['_HEATPUMPPERMISSION']._serialized_end=1018
  _globals['_ADDHEATPUMPPERMISSIONSREQUEST']._serialized_start=1021
  _globals['_ADDHEATPUMPPERMISSIONSREQUEST']._serialized_end=1152
  _globals['_ADDHEATPUMPPERMISSIONSRESPONSE']._serialized_start=1154
  _globals['_ADDHEATPUMPPERMISSIONSRESPONSE']._serialized_end=1186
  _globals['_USERACCOUNT']._serialized_start=1189
  _globals['_USERACCOUNT']._serialized_end=1601
  _globals['_INSTALLERACCOUNT']._serialized_start=1604
  _globals['_INSTALLERACCOUNT']._serialized_end=1864
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_start=1866
  _globals['_GETUSERACCOUNTBYCOGNITOIDREQUEST']._serialized_end=1935
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_start=1938
  _globals['_GETUSERACCOUNTBYCOGNITOIDRESPONSE']._serialized_end=2079
  _globals['_GETUSERACCOUNTBYUSERIDREQUEST']._serialized_start=2081
  _globals['_GETUSERACCOUNTBYUSERIDREQUEST']._serialized_end=2144
  _globals['_GETUSERACCOUNTBYUSERIDRESPONSE']._serialized_start=2146
  _globals['_GETUSERACCOUNTBYUSERIDRESPONSE']._serialized_end=2230
  _globals['_GETUSERACCOUNTBYCONTACTIDREQUEST']._serialized_start=2232
  _globals['_GETUSERACCOUNTBYCONTACTIDREQUEST']._serialized_end=2301
  _globals['_GETUSERACCOUNTBYCONTACTIDRESPONSE']._serialized_start=2303
  _globals['_GETUSERACCOUNTBYCONTACTIDRESPONSE']._serialized_end=2396
  _globals['_CREATEUSERACCOUNTREQUEST']._serialized_start=2399
  _globals['_CREATEUSERACCOUNTREQUEST']._serialized_end=2669
  _globals['_CREATEUSERACCOUNTRESPONSE']._serialized_start=2671
  _globals['_CREATEUSERACCOUNTRESPONSE']._serialized_end=2750
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_start=2753
  _globals['_UPDATEUSERACCOUNTREQUEST']._serialized_end=3011
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_start=3013
  _globals['_UPDATEUSERACCOUNTRESPONSE']._serialized_end=3092
  _globals['_LEGALDOCUMENT']._serialized_start=3095
  _globals['_LEGALDOCUMENT']._serialized_end=3290
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_start=3293
  _globals['_LEGALDOCUMENTUSERAGREEMENT']._serialized_end=3458
  _globals['_GETALLUSERAGREEMENTSREQUEST']._serialized_start=3460
  _globals['_GETALLUSERAGREEMENTSREQUEST']._serialized_end=3521
  _globals['_GETALLUSERAGREEMENTSRESPONSE']._serialized_start=3523
  _globals['_GETALLUSERAGREEMENTSRESPONSE']._serialized_end=3618
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_start=3620
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTREQUEST']._serialized_end=3735
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_start=3737
  _globals['_CREATELEGALDOCUMENTUSERAGREEMENTRESPONSE']._serialized_end=3779
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_start=3781
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSREQUEST']._serialized_end=3857
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_start=3859
  _globals['_USERHASACCEPTEDLATESTLEGALDOCUMENTSRESPONSE']._serialized_end=3969
  _globals['_LEGALDOCUMENTUSERAGREEMENTENTITY']._serialized_start=3971
  _globals['_LEGALDOCUMENTUSERAGREEMENTENTITY']._serialized_end=4069
  _globals['_ADMINUPDATEUSERREQUEST']._serialized_start=4072
  _globals['_ADMINUPDATEUSERREQUEST']._serialized_end=4543
  _globals['_ADMINUPDATEUSERRESPONSE']._serialized_start=4545
  _globals['_ADMINUPDATEUSERRESPONSE']._serialized_end=4570
  _globals['_ADMINCREATEUSERREQUEST']._serialized_start=4573
  _globals['_ADMINCREATEUSERREQUEST']._serialized_end=4830
  _globals['_ADMINCREATEUSERRESPONSE']._serialized_start=4832
  _globals['_ADMINCREATEUSERRESPONSE']._serialized_end=4857
  _globals['_ADMINCREATEINSTALLERACCOUNTREQUEST']._serialized_start=4860
  _globals['_ADMINCREATEINSTALLERACCOUNTREQUEST']._serialized_end=5071
  _globals['_ADMINCREATEINSTALLERACCOUNTRESPONSE']._serialized_start=5073
  _globals['_ADMINCREATEINSTALLERACCOUNTRESPONSE']._serialized_end=5172
  _globals['_ADMINUPDATEINSTALLERACCOUNTREQUEST']._serialized_start=5175
  _globals['_ADMINUPDATEINSTALLERACCOUNTREQUEST']._serialized_end=5403
  _globals['_ADMINUPDATEINSTALLERACCOUNTRESPONSE']._serialized_start=5405
  _globals['_ADMINUPDATEINSTALLERACCOUNTRESPONSE']._serialized_end=5504
  _globals['_ADMINFINDINSTALLERACCOUNTREQUEST']._serialized_start=5506
  _globals['_ADMINFINDINSTALLERACCOUNTREQUEST']._serialized_end=5590
  _globals['_ADMINFINDINSTALLERACCOUNTRESPONSE']._serialized_start=5592
  _globals['_ADMINFINDINSTALLERACCOUNTRESPONSE']._serialized_end=5689
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDREQUEST']._serialized_start=5691
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDREQUEST']._serialized_end=5764
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDRESPONSE']._serialized_start=5766
  _globals['_GETUSERACCOUNTSBYHEATPUMPIDRESPONSE']._serialized_end=5855
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_start=5857
  _globals['_GETHOUSEHOLDSBYUSERIDREQUEST']._serialized_end=5934
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_start=5936
  _globals['_GETHOUSEHOLDSBYUSERIDRESPONSE']._serialized_end=6019
  _globals['_HOUSEHOLD']._serialized_start=6022
  _globals['_HOUSEHOLD']._serialized_end=6206
  _globals['_HEATPUMP']._serialized_start=6208
  _globals['_HEATPUMP']._serialized_end=6249
  _globals['_RESIDENT']._serialized_start=6252
  _globals['_RESIDENT']._serialized_end=6439
  _globals['_DELETERESIDENTREQUEST']._serialized_start=6442
  _globals['_DELETERESIDENTREQUEST']._serialized_end=6603
  _globals['_DELETERESIDENTRESPONSE']._serialized_start=6605
  _globals['_DELETERESIDENTRESPONSE']._serialized_end=6633
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_start=6635
  _globals['_GETPROXIMITYVERIFICATIONSTATUSREQUEST']._serialized_end=6674
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_start=6676
  _globals['_GETPROXIMITYVERIFICATIONSTATUSRESPONSE']._serialized_end=6791
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_start=6793
  _globals['_VERIFYPROXIMITYREQUEST']._serialized_end=6861
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_start=6863
  _globals['_VERIFYPROXIMITYRESPONSE']._serialized_end=6921
  _globals['_USERACCOUNTSERVICE']._serialized_start=7417
  _globals['_USERACCOUNTSERVICE']._serialized_end=10205
# @@protoc_insertion_point(module_scope)